@@ -24,6 +24,10 @@ except ImportError:
 
 
 globalLogName = "physbibliolog"
+if six.PY2:
+    FNFError = OSError
+else:
+    FNFError = FileNotFoundError
 
 
 class ConfigParameter:
@@ -265,6 +269,14 @@ configuration_params.add(
         isGlobal=True,
     )
 )
+configuration_params.add(
+    ConfigParameter(
+        "batchSizeInspire",
+        50,
+        description=cstr.Desc.limitBibtexs,
+        special="int",
+    )
+)
 
 ignoreParameterOrder = ["mainDatabaseName", "openSinceLastUpdate"]
 loggingLevels = ["0 - errors", "1 - warnings", "2 - info", "3 - all"]
@@ -295,6 +307,7 @@ class GlobalDB(PhysBiblioDBCore):
 
         if self.countProfiles() == 0:
             self.createProfile()
+        self.checkOnlyFilename()
 
         self.config = ConfigurationDB(self)
 
@@ -334,9 +347,10 @@ class GlobalDB(PhysBiblioDBCore):
             True if successful, sys.exit(1) otherwise
         """
         if databasefile is None:
-            databasefile = os.path.join(
-                self.dataPath,
-                configuration_params["mainDatabaseName"].default.replace("PBDATA", ""),
+            databasefile = (
+                configuration_params["mainDatabaseName"]
+                .default.replace("PBDATA", "")
+                .replace(self.dataPath, "")
             )
         command = (
             "INSERT into profiles "
@@ -545,6 +559,16 @@ class GlobalDB(PhysBiblioDBCore):
             self.logger.warning(cstr.errorNoProfilesName)
             return False
 
+    def checkOnlyFilename(self):
+        """Convert previously stored profile names"""
+        for q in self.getProfiles():
+            if q["databasefile"].startswith(self.dataPath):
+                self.updateProfileField(
+                    q["name"],
+                    "databasefile",
+                    q["databasefile"].replace(self.dataPath, ""),
+                )
+
     def countSearches(self):
         """Obtain the number of searches in the table
 
@@ -826,16 +850,41 @@ def getLogLevel(value):
         return logging.DEBUG
 
 
-def addFileHandler(logger, logFileName):
+def replacePBDATA(path, var):
+    """Replace the PBDATA placeholder in the given variable,
+    if it is a string, or just return the variable otherwise
+
+    Parameters:
+        var: the input variable
+
+    Output:
+        the input variable or a string with replaced "PBDATA"
+    """
+    if isinstance(var, six.string_types) and "PBDATA" in var:
+        var = os.path.join(path, var.replace("PBDATA", ""))
+    return var
+
+
+def addFileHandler(logger, logFileName, defaultPath=""):
     """Create and add a RotatingFileHandler to an existing Logger
 
     Parameters:
         logger: an existing instance of logging.Logger
         logFileName: the name of the log file
+        defaultPath (default ""): used in case the logFileName is missing
+            to point to the default log file name in the default folder
     """
-    fh = logging.handlers.RotatingFileHandler(
-        logFileName, maxBytes=5.0 * 2 ** 20, backupCount=5
-    )
+    try:
+        fh = logging.handlers.RotatingFileHandler(
+            logFileName, maxBytes=5.0 * 2 ** 20, backupCount=5
+        )
+    except FNFError:
+        logger.exception("")
+        fh = logging.handlers.RotatingFileHandler(
+            replacePBDATA(defaultPath, configuration_params["logFileName"].default),
+            maxBytes=5.0 * 2 ** 20,
+            backupCount=5,
+        )
     fh.setLevel(getLogLevel(pbConfig.params["loggingLevel"]))
     formatter = logging.Formatter(
         "%(asctime)s %(levelname)10s : [%(module)s.%(funcName)s] %(message)s"
@@ -857,7 +906,6 @@ class ConfigVars:
     inspireExperimentsLink = "https://inspirehep.net/experiments/"
     inspireLiteratureAPI = "https://inspirehep.net/api/literature/"
     inspireLiteratureLink = "https://inspirehep.net/literature/"
-    inspireOAI = "https://old.inspirehep.net/oai2d"
 
     def __init__(self, profileFileName="profiles.db"):
         """Initialize the configuration.
@@ -959,7 +1007,9 @@ class ConfigVars:
                 rfhs.append(lh)
         for lh in rfhs:
             self.logger.removeHandler(lh)
-        addFileHandler(self.logger, self.params["logFileName"])
+        addFileHandler(
+            self.logger, self.params["logFileName"], defaultPath=self.dataPath
+        )
         self.logger.debug(cstr.confLoaded)
 
     def readParam(self, key, configDb):
@@ -1016,7 +1066,9 @@ class ConfigVars:
                 "n": e["name"],
                 "d": e["description"],
                 "f": e["oldCfg"],
-                "db": e["databasefile"],
+                "db": e["databasefile"]
+                if os.sep in e["databasefile"]
+                else os.path.join(self.dataPath, e["databasefile"]),
             }
         return (
             self.globalDb.getDefaultProfile(),
@@ -1040,7 +1092,11 @@ class ConfigVars:
                 return
         self.currentProfileName = newShort
         self.currentProfile = newProfile
-        self.currentDatabase = newProfile["db"]
+        self.currentDatabase = (
+            newProfile["db"]
+            if os.sep in newProfile["db"]
+            else os.path.join(self.dataPath, newProfile["db"])
+        )
         self.setDefaultParams()
         self.logger.info(
             cstr.restartWProfile % (self.currentProfileName, self.currentDatabase)
@@ -1068,7 +1124,11 @@ class ConfigVars:
             )
             self.currentProfileName = self.defaultProfileName
             self.currentProfile = self.profiles[self.currentProfileName]
-        self.currentDatabase = self.currentProfile["db"]
+        self.currentDatabase = (
+            self.currentProfile["db"]
+            if os.sep in self.currentProfile["db"]
+            else os.path.join(self.dataPath, self.currentProfile["db"])
+        )
         self.logger.info(
             cstr.startWProfile % (self.currentProfileName, self.currentDatabase)
         )
@@ -1085,9 +1145,7 @@ class ConfigVars:
         Output:
             the input variable or a string with replaced "PBDATA"
         """
-        if isinstance(var, six.string_types) and "PBDATA" in var:
-            var = os.path.join(self.dataPath, var.replace("PBDATA", ""))
-        return var
+        return replacePBDATA(self.dataPath, var)
 
     def setDefaultParams(self):
         """Reset the list of params,
