@@ -3,10 +3,16 @@ in the other physbiblio.gui modules.
 
 This file is part of the physbiblio package.
 """
+import sys
 import time
 import traceback
 from weakref import WeakValueDictionary
 
+if sys.version_info[0] < 3:
+    from Queue import Empty
+else:
+    from queue import Empty
+
 import PySide2
 from PySide2.QtCore import (
     QAbstractItemModel,
@@ -19,12 +25,11 @@ from PySide2.QtCore import (
     QUrl,
     Signal,
 )
-from PySide2.QtGui import QDesktopServices, QPainter, QPixmap
+from PySide2.QtGui import QDesktopServices, QGuiApplication, QPainter, QPixmap
 from PySide2.QtWidgets import (
     QAbstractItemView,
     QAction,
     QComboBox,
-    QDesktopWidget,
     QDialog,
     QGridLayout,
     QLabel,
@@ -61,11 +66,11 @@ class PBDialog(QDialog):
     """Extend QDialog with centerWindow"""
 
     def centerWindow(self):
-        """Use the `QDesktopWidget` to get the relevant information
+        """Use the `QGuiApplication` to get the relevant information
         and center the dialog in the screen.
         """
         qr = self.frameGeometry()
-        cp = QDesktopWidget().availableGeometry().center()
+        cp = QGuiApplication.primaryScreen().availableGeometry().center()
         qr.moveCenter(cp)
         self.move(qr.topLeft())
 
@@ -294,8 +299,8 @@ class ObjListWindow(PBDialog):
         """
         self.tableview.resizeColumnsToContents()
 
-        maxh = QDesktopWidget().availableGeometry().height()
-        maxw = QDesktopWidget().availableGeometry().width()
+        maxh = QGuiApplication.primaryScreen().availableGeometry().height()
+        maxw = QGuiApplication.primaryScreen().availableGeometry().width()
         self.setMaximumHeight(maxh)
         self.setMaximumWidth(maxw)
 
@@ -430,8 +435,18 @@ class WriteStream(PBThread):
 
     def run(self):
         """Run the thread"""
+        last = time.time()
+        text = ""
         while self.running:
-            text = self.queue.get()
+            try:
+                text += self.queue.get(timeout=0.2)
+            except Empty:
+                pass
+            if text != "" and (len(text) > 1000 or time.time() - last > 0.1):
+                self.newText.emit(text)
+                last = time.time()
+                text = ""
+        if text != "":
             self.newText.emit(text)
         self.finished.emit()
 
