@@ -12,11 +12,10 @@ import traceback
 import bibtexparser
 import six
 from PySide2.QtCore import Qt, Signal
-from PySide2.QtGui import QIcon, QPixmap
+from PySide2.QtGui import QGuiApplication, QIcon, QPixmap
 from PySide2.QtWidgets import (
     QAction,
     QApplication,
-    QDesktopWidget,
     QFrame,
     QMainWindow,
     QMessageBox,
@@ -79,6 +78,7 @@ try:
     from physbiblio.gui.threadElements import (
         Thread_authorStats,
         Thread_checkUpdated,
+        Thread_citationCount,
         Thread_cleanAllBibtexs,
         Thread_cleanSpare,
         Thread_cleanSparePDF,
@@ -125,8 +125,8 @@ class MainWindow(QMainWindow):
         """
         QMainWindow.__init__(self)
         self.errormessage.connect(self.excepthook)
-        availableWidth = QDesktopWidget().availableGeometry().width()
-        availableHeight = QDesktopWidget().availableGeometry().height()
+        availableWidth = QGuiApplication.primaryScreen().availableGeometry().width()
+        availableHeight = QGuiApplication.primaryScreen().availableGeometry().height()
         self.setWindowTitle(mwstr.winTitle)
         # x,y of topleft corner, width, height
         self.setGeometry(0, 0, availableWidth, availableHeight)
@@ -250,6 +250,33 @@ class MainWindow(QMainWindow):
         appIcon = QIcon(":/images/icon.png")
         self.setWindowIcon(appIcon)
 
+    def keyPressEvent(self, e):
+        """Manage the key press events.
+
+        Parameters:
+            e: the `PySide2.QtGui.QKeyEvent`
+        """
+        modifiers = QApplication.keyboardModifiers()
+        if e.key() == Qt.Key_W and modifiers == Qt.ControlModifier:
+            self.closeTab(self.tabWidget.currentIndex())
+        elif e.key() == Qt.Key_N and modifiers == (
+            Qt.ControlModifier | Qt.ShiftModifier
+        ):
+            self.newTabAtEnd(self.tabWidget.count() - 1)
+        elif e.key() == Qt.Key_Tab and modifiers == (Qt.ControlModifier):
+            index = self.tabWidget.currentIndex()
+            self.tabWidget.setCurrentIndex(
+                index + 1 if index < self.tabWidget.count() - 2 else 0
+            )
+        elif (e.key() == Qt.Key_Backtab and modifiers == Qt.ControlModifier) or (
+            e.key() == Qt.Key_Backtab
+            and modifiers == (Qt.ControlModifier | Qt.ShiftModifier)
+        ):
+            index = self.tabWidget.currentIndex()
+            self.tabWidget.setCurrentIndex(
+                index - 1 if index > 0 else self.tabWidget.count() - 2
+            )
+
     def createActions(self):
         """Create the QActions used in menu and in the toolbar."""
         self.exitAct = QAction(
@@ -436,6 +463,13 @@ class MainWindow(QMainWindow):
             triggered=self.updateAllBibtexsAsk,
         )
 
+        self.updateCitationCountAct = QAction(
+            mwstr.Act.ccT,
+            self,
+            statusTip=mwstr.Act.ccD,
+            triggered=self.getInspireCitationCount,
+        )
+
         self.cleanAllBibtexsAct = QAction(
             mwstr.Act.cleBT,
             self,
@@ -588,6 +622,7 @@ class MainWindow(QMainWindow):
         self.bibMenu.addAction(self.infoFromArxivAct)
         self.bibMenu.addAction(self.updateAllBibtexsAct)
         self.bibMenu.addAction(self.updateAllBibtexsAskAct)
+        self.bibMenu.addAction(self.updateCitationCountAct)
         self.bibMenu.addSeparator()
         self.bibMenu.addAction(self.searchBibAct)
         self.bibMenu.addAction(self.searchReplaceAct)
@@ -622,7 +657,9 @@ class MainWindow(QMainWindow):
                         self,
                         triggered=lambda sD=ast.literal_eval(fs["searchDict"]), l=fs[
                             "limitNum"
-                        ], o=fs["offsetNum"]: self.runSearchBiblio(sD, l, o),
+                        ], o=fs["offsetNum"], n=fs["name"]: self.runSearchBiblio(
+                            sD, l, o, newTab=n
+                        ),
                     )
                 )
             self.searchMenu.addSeparator()
@@ -670,8 +707,10 @@ class MainWindow(QMainWindow):
                             fs["searchDict"]
                         ), r=ast.literal_eval(fs["replaceFields"]), o=fs[
                             "offsetNum"
+                        ], n=fs[
+                            "name"
                         ]: self.runSearchReplaceBiblio(
-                            sD, r, o
+                            sD, r, o, newTab=n
                         ),
                     )
                 )
@@ -768,8 +807,8 @@ class MainWindow(QMainWindow):
         splitter.setStretchFactor(0, 3)
         splitter.setStretchFactor(1, 1)
 
-        availableWidth = QDesktopWidget().availableGeometry().width()
-        availableHeight = QDesktopWidget().availableGeometry().height()
+        availableWidth = QGuiApplication.primaryScreen().availableGeometry().width()
+        availableHeight = QGuiApplication.primaryScreen().availableGeometry().height()
         splitter.setGeometry(0, 0, availableWidth, availableHeight)
 
         self.setCentralWidget(splitter)
@@ -813,7 +852,10 @@ class MainWindow(QMainWindow):
         self.tabWidget.addTab(QWidget(self), QIcon(":/images/file-add.png"), "")
         # hide close buttons for first and last tabs
         for i in [0, self.tabWidget.count() - 1]:
-            self.tabWidget.tabBar().tabButton(i, QTabBar.RightSide).deleteLater()
+            try:
+                self.tabWidget.tabBar().tabButton(i, QTabBar.RightSide).deleteLater()
+            except AttributeError:
+                pBLogger.debug("", exc_info=True)
             self.tabWidget.tabBar().setTabButton(i, QTabBar.RightSide, None)
         self.tabWidget.blockSignals(False)
 
@@ -838,24 +880,33 @@ class MainWindow(QMainWindow):
         Parameter:
             index: the index of the tab to be deleted
         """
+        closed = False
         if index != 0 and index != self.tabWidget.count() - 1:
             try:
                 del self.bibtexListWindows[index]
             except IndexError:
                 pass
+            else:
+                closed = True
         self.fillTabs()
+        if closed:
+            self.tabWidget.setCurrentIndex(index - 1)
 
-    def newTabAtEnd(self, index, bibs=None, askBibs=False, previous=[]):
+    def newTabAtEnd(self, index, label=None, bibs=None, askBibs=False, previous=[]):
         """Function that checks if the "open new tab" tab is triggered.
         If yes, create a new bibtexListWindow and recreate the tabWidget
 
         Parameters:
             index: the index of the clicked tab
+            label (default None): if not None, the label of the new tab
             bibs, askBibs, previous: directly passed to BibtexListWindow
         """
         if self.tabWidget.count() > 1 and index == self.tabWidget.count() - 1:
             self.addBibtexListWindow(
-                mwstr.newTab, bibs=bibs, askBibs=askBibs, previous=previous
+                mwstr.newTab if label is None else label,
+                bibs=bibs,
+                askBibs=askBibs,
+                previous=previous,
             )
             self.fillTabs()
             self.tabWidget.setCurrentIndex(index)
@@ -892,10 +943,16 @@ class MainWindow(QMainWindow):
         self.currentTabWidget().recreateTable(pBDB.bibs.fetchFromLast().lastFetched)
         self.done()
 
-    def reloadMainContent(self, bibs=None):
+    def reloadMainContent(self, bibs=None, newTab=None):
         """Delete the previous table widget and create a new one,
         using the default query
+
+        Parameters:
+            bibs (default None): the list of bibtexs to show in the table
+            newTab (default None): if not None, the label of the new tab
         """
+        if newTab:
+            self.newTabAtEnd(self.tabWidget.count() - 1, label=newTab)
         self.statusBarMessage(mwstr.reloadMain)
         self.currentTabWidget().recreateTable(bibs)
         self.done()
@@ -1316,6 +1373,8 @@ class MainWindow(QMainWindow):
                         offset=offs,
                         replaceFields=replaceFields,
                     )
+                if newSearchWin.newTabCheck.isChecked():
+                    self.newTabAtEnd(self.tabWidget.count() - 1, label=mwstr.newTab)
                 noLim = pBDB.bibs.fetchFromDict(
                     searchFields, limitOffset=offs, doFetch=False
                 )
@@ -1355,11 +1414,16 @@ class MainWindow(QMainWindow):
                     limit=lim,
                     offset=offs,
                 )
-            self.runSearchBiblio(searchFields, lim, offs)
+            self.runSearchBiblio(
+                searchFields,
+                lim,
+                offs,
+                newTab=mwstr.newTab if newSearchWin.newTabCheck.isChecked() else None,
+            )
         elif replace:
             return False
 
-    def runSearchBiblio(self, searchFields, lim, offs):
+    def runSearchBiblio(self, searchFields, lim, offs, newTab=None):
         """Run a search with some parameters
 
         Parameters:
@@ -1368,7 +1432,10 @@ class MainWindow(QMainWindow):
                 to be used in `database.Entries.fetchFromDict`
             lim: the maximum number of entries to fetch
             offs: the offset for the search
+            newTab (default None): if not None, the label of the new tab
         """
+        if newTab is not None:
+            self.newTabAtEnd(self.tabWidget.count() - 1, label=newTab)
         QApplication.setOverrideCursor(Qt.WaitCursor)
         noLim = pBDB.bibs.fetchFromDict(searchFields, limitOffset=offs).lastFetched
         lastFetched = pBDB.bibs.fetchFromDict(
@@ -1379,7 +1446,7 @@ class MainWindow(QMainWindow):
         self.reloadMainContent(lastFetched)
         QApplication.restoreOverrideCursor()
 
-    def runSearchReplaceBiblio(self, searchFields, replaceFields, offs):
+    def runSearchReplaceBiblio(self, searchFields, replaceFields, offs, newTab=None):
         """Run a search&replace with some parameters
 
         Parameters:
@@ -1389,9 +1456,10 @@ class MainWindow(QMainWindow):
             replaceFields: a tuple/list of 5 elements,
                 as in the output of `self.searchBiblio`
             offs: the offset for the search
+            newTab (default None): if not None, the label of the new tab
         """
         pBDB.bibs.fetchFromDict(searchFields, limitOffset=offs)
-        self.runReplace(replaceFields)
+        self.runReplace(replaceFields, newTab=newTab)
 
     def renameSearchBiblio(self, idS, oldname):
         """Rename a saved search
@@ -1445,14 +1513,26 @@ class MainWindow(QMainWindow):
                     )
                     pbConfig.globalDb.commit()
                 pBDB.bibs.fetchFromDict(searchFields, limitOffset=offs)
-                self.runReplace(replaceFields)
+                self.runReplace(
+                    replaceFields,
+                    newTab=mwstr.newTab
+                    if newSearchWin.newTabCheck.isChecked()
+                    else None,
+                )
             else:
                 if newSearchWin.save:
                     pbConfig.globalDb.updateSearchField(idS, "searchDict", searchFields)
                     pbConfig.globalDb.updateSearchField(idS, "limitNum", lim)
                     pbConfig.globalDb.updateSearchField(idS, "offsetNum", offs)
                     pbConfig.globalDb.commit()
-                self.runSearchBiblio(searchFields, lim, offs)
+                self.runSearchBiblio(
+                    searchFields,
+                    lim,
+                    offs,
+                    newTab=mwstr.newTab
+                    if newSearchWin.newTabCheck.isChecked()
+                    else None,
+                )
 
     def delSearchBiblio(self, idS, name):
         """Delete a saved search from the database
@@ -1474,13 +1554,14 @@ class MainWindow(QMainWindow):
             return
         self.runReplace(result)
 
-    def runReplace(self, replace):
+    def runReplace(self, replace, newTab=None):
         """Run the `database.Entries.replace` function,
         then print some output in a dialog
 
         Parameter:
             replace: a tuple/list of 5 elements,
                 as in the output of `self.searchBiblio`
+            newTab (default None): if not None, the label of the new tab
         """
         regex = replace["regex"]
         fiOld = replace["fieOld"]
@@ -1519,7 +1600,7 @@ class MainWindow(QMainWindow):
             )
         )
         QApplication.setOverrideCursor(Qt.WaitCursor)
-        self.reloadMainContent(pBDB.bibs.fetchFromLast().lastFetched)
+        self.reloadMainContent(pBDB.bibs.fetchFromLast().lastFetched, newTab=newTab)
         QApplication.restoreOverrideCursor()
 
     def updateAllBibtexsAsk(self):
@@ -1648,6 +1729,27 @@ class MainWindow(QMainWindow):
         self.done()
         return True
 
+    def getInspireCitationCount(self, inspireID=[]):
+        """Use a thread to obtain the citation statistics
+        of a paper using the INSPIRE-HEP database
+
+        Parameter:
+            inspireID: the ID of the paper in the INSPIRE database
+        """
+        if not isinstance(inspireID, list):
+            inspireID = [inspireID]
+        if inspireID == []:
+            inspireID = [e["inspire"] for e in pBDB.bibs.getAll()]
+        inspireID = [i for i in inspireID if i != "" and i is not None]
+        self._runInThread(
+            Thread_citationCount,
+            mwstr.citCount,
+            inspireID,
+            minProgress=0.0,
+            stopFlag=True,
+        )
+        self.done()
+
     def getInspireStats(self, inspireId):
         """Use a thread to obtain the citation statistics
         of a paper using the INSPIRE-HEP database
@@ -1775,11 +1877,7 @@ class MainWindow(QMainWindow):
             QApplication.setOverrideCursor(Qt.WaitCursor)
             cont = physBiblioWeb.webSearch[method].retrieveUrlAll(string)
             if cont.strip() != "":
-                elements = (
-                    bibtexparser.bparser.BibTexParser(common_strings=True)
-                    .parse(cont)
-                    .entries
-                )
+                elements = pBDB.bibs.readEntries(cont)
             else:
                 elements = []
             found = {}
@@ -1843,8 +1941,8 @@ class MainWindow(QMainWindow):
                             pBDB.bibs.setBook(key)
                         pBLogger.info(mwstr.elementInserted % key)
                         inserted.append(key)
-                    except:
-                        pBLogger.warning(mwstr.failedComplete % key)
+                    except Exception:
+                        pBLogger.warning(mwstr.failedComplete % key, exc_info=True)
                 self.statusBarMessage(mwstr.elementImported % (inserted))
                 if selImpo.askCats.isChecked():
                     for key in inserted:
