@@ -20,7 +20,7 @@ from PySide2.QtCore import (
 )
 from PySide2.QtGui import QContextMenuEvent, QDropEvent
 from PySide2.QtTest import QTest
-from PySide2.QtWidgets import QAction, QDesktopWidget, QInputDialog, QLineEdit, QWidget
+from PySide2.QtWidgets import QAction, QInputDialog, QLineEdit, QWidget
 
 if sys.version_info[0] < 3:
     import unittest2 as unittest
@@ -336,9 +336,10 @@ class TestObjListWindow(GUITestCase):
             _rc.assert_has_calls([call(), call()])
             self.assertEqual(_rr.call_count, 1)
         self.assertIsInstance(olw.tableview, PBTableView)
-        maxw = QDesktopWidget().availableGeometry().width()
+        maxw = QGuiApplication.primaryScreen().availableGeometry().width()
         self.assertEqual(
-            olw.maximumHeight(), QDesktopWidget().availableGeometry().height()
+            olw.maximumHeight(),
+            QGuiApplication.primaryScreen().availableGeometry().height(),
         )
         self.assertEqual(olw.maximumWidth(), maxw)
         hwidth = olw.tableview.horizontalHeader().length()
@@ -414,9 +415,9 @@ class TestEditObjectWindow(GUITestCase):
             "physbiblio.gui.commonClasses.EditObjectWindow.onCancel", autospec=True
         ) as _oc:
             QTest.keyPress(w, "a")
-            self.assertEqual(_oc.call_count, 0)
+            _oc.assert_not_called()
             QTest.keyPress(w, Qt.Key_Enter)
-            self.assertEqual(_oc.call_count, 0)
+            _oc.assert_not_called()
             QTest.keyPress(w, Qt.Key_Escape)
             self.assertEqual(_oc.call_count, 1)
 
@@ -493,25 +494,87 @@ class TestWriteStream(GUITestCase):
         self.assertEqual(ws.parent(), ew)
         ws.finished.connect(lambda: fakeExec_writeStream_fin(ws))
         if sys.version_info[0] < 3:
-            with patch("Queue.Queue.put", autospec=True) as _put:
-                ws.write("abc")
-                _put.assert_called_once_with(queue, "abc")
-            with patch("Queue.Queue.get", return_value="abc", autospec=True) as _get:
-                ws.newText.connect(lambda x: fakeExec_writeStream_mys(ws, x))
-                ws.run()
-                self.assertEqual(_get.call_count, 1)
-                self.assertEqual(ws.text, "abc")
-                self.assertTrue(ws.fin)
+            package = "Queue"
         else:
-            with patch("queue.Queue.put", autospec=True) as _put:
-                ws.write("abc")
-                _put.assert_called_once_with(queue, "abc")
-            with patch("queue.Queue.get", return_value="abc", autospec=True) as _get:
-                ws.newText.connect(lambda x: fakeExec_writeStream_mys(ws, x))
-                ws.run()
-                self.assertEqual(_get.call_count, 1)
-                self.assertEqual(ws.text, "abc")
-                self.assertTrue(ws.fin)
+            package = "queue"
+        with patch(package + ".Queue.put", autospec=True) as _put:
+            ws.write("abc")
+            _put.assert_called_once_with(queue, "abc")
+        with patch(package + ".Queue.get", return_value="abc", autospec=True) as _get:
+            ws.newText.connect(lambda x: fakeExec_writeStream_mys(ws, x))
+            ws.run()
+            self.assertEqual(_get.call_count, 334)
+            _get.assert_any_call(ws.queue, timeout=0.2)
+            self.assertEqual(ws.text, "abc" * _get.call_count)
+            self.assertTrue(ws.fin)
+
+            _get.reset_mock()
+            _get.return_value = "abcde" * 100
+            ws.running = True
+            ws.run()
+            self.assertEqual(_get.call_count, 3)
+            _get.assert_any_call(ws.queue, timeout=0.2)
+            self.assertEqual(ws.text, "abcde" * 100 * _get.call_count)
+            self.assertTrue(ws.fin)
+
+            _get.reset_mock()
+            _get.return_value = "abcde" * 201
+            ws.running = True
+            ws.run()
+            self.assertEqual(_get.call_count, 1)
+            _get.assert_any_call(ws.queue, timeout=0.2)
+            self.assertEqual(ws.text, "abcde" * 201)
+
+            _get.reset_mock()
+
+            def getWait(x, timeout=0.2):
+                time.sleep(timeout / 5.0)
+                return "abcde"
+
+            _get.side_effect = getWait
+            ws.running = True
+            ws.run()
+            self.assertEqual(_get.call_count, 3)
+            _get.assert_any_call(ws.queue, timeout=0.2)
+            self.assertEqual(ws.text, "abcde" * 3)
+
+            _get.reset_mock()
+            self.a = 0
+
+            def getWaitLong(ws, timeout=0.2):
+                self.a += 1
+                time.sleep(timeout)
+                if self.a > 2:
+                    return "abcde"
+                else:
+                    return ""
+
+            _get.side_effect = getWaitLong
+            ws.running = True
+            ws.run()
+            self.assertEqual(_get.call_count, 3)
+            _get.assert_any_call(ws.queue, timeout=0.2)
+            self.assertEqual(ws.text, "abcde")
+
+            _get.reset_mock()
+            self.a = 0
+
+            def getWaitEmpty(q, timeout=0.2):
+                self.a += 1
+                time.sleep(timeout / 21.0)
+                if self.a > 4:
+                    ws.running = False
+                    return ""
+                else:
+                    return "a"
+
+            _get.side_effect = getWaitEmpty
+            ws.running = True
+            ws.run()
+            self.assertEqual(_get.call_count, 5)
+            _get.assert_any_call(ws.queue, timeout=0.2)
+            self.assertEqual(ws.text, "aaaa")
+        ws.running = False
 
 
 @unittest.skipIf(skipTestsSettings.gui, "GUI tests")
@@ -671,7 +734,7 @@ class TestPBTableModel(GUITestCase):
         ) as _gi, patch("logging.Logger.exception") as _ex:
             mtm.prepareSelected()
             _ex.assert_called_once_with("dataList is not defined!")
-            self.assertEqual(_gi.call_count, 0)
+            _gi.assert_not_called()
         self.assertEqual(mtm.selectedElements, {})
 
     def test_un_selectAll(self):
@@ -1054,8 +1117,8 @@ class TestLeafFilterProxyModel(GUITestCase):
         ) as _chi:
             self.assertTrue(lf.filterAcceptsRow(0, None))
             _its.assert_called_once_with(lf, 0, None)
-            self.assertEqual(_par.call_count, 0)
-            self.assertEqual(_chi.call_count, 0)
+            _par.assert_not_called()
+            _chi.assert_not_called()
         with patch(
             "physbiblio.gui.commonClasses.LeafFilterProxyModel."
             + "filterAcceptsRowItself",
@@ -1074,7 +1137,7 @@ class TestLeafFilterProxyModel(GUITestCase):
             self.assertTrue(lf.filterAcceptsRow(0, None))
             _its.assert_called_once_with(lf, 0, None)
             _par.assert_called_once_with(lf, None)
-            self.assertEqual(_chi.call_count, 0)
+            _chi.assert_not_called()
         with patch(
             "physbiblio.gui.commonClasses.LeafFilterProxyModel."
             + "filterAcceptsRowItself",
@@ -1443,9 +1506,9 @@ class TestPBMenu(GUITestCase):
         mm = PBMenu()
         with patch("physbiblio.gui.commonClasses.QMenu.close", autospec=True) as _oc:
             QTest.keyPress(mm, "a")
-            self.assertEqual(_oc.call_count, 0)
+            _oc.assert_not_called()
             QTest.keyPress(mm, Qt.Key_Enter)
-            self.assertEqual(_oc.call_count, 0)
+            _oc.assert_not_called()
             QTest.keyPress(mm, Qt.Key_Escape)
             self.assertEqual(_oc.call_count, 1)
 
