@@ -50,7 +50,6 @@ class SkipTestsSettingsClass:
         new.db = bool(self.db)
         new.gui = bool(self.gui)
         new.long = bool(self.long)
-        new.oai = bool(self.oai)
         new.online = bool(self.online)
         return new
 
@@ -59,17 +58,15 @@ class SkipTestsSettingsClass:
         self.db = False
         self.gui = False
         self.long = False
-        self.oai = False
         self.online = False
 
     def __str__(self):
         """print current settings"""
-        return "DB: %s\nGUI: %s\nlong: %s\nOnline: %s (OAI: %s)" % (
+        return "DB: %s\nGUI: %s\nlong: %s\nOnline: %s" % (
             self.db,
             self.gui,
             self.long,
             self.online,
-            self.oai,
         )
 
 
@@ -86,11 +83,19 @@ if os.path.exists(tempFDBName):
     os.remove(tempFDBName)
 
 
+class NameSpace:
+    pass
+
+
 class DBTestCase(unittest.TestCase):
     """define the class that will be used for database tests"""
 
     @classmethod
-    def setUpClass(self):
+    @patch("logging.Logger.debug")
+    @patch("logging.Logger.info")
+    @patch("logging.Logger.warning")
+    @patch("logging.Logger.exception")
+    def setUpClass(self, *args):
         """Create a temporary database"""
         self.maxDiff = None
         self.pBDB = PhysBiblioDB(tempDBName, pBLogger)
