@@ -24,6 +24,7 @@ class CommonGUIStrings:
     nothingChanged = "Nothing changed"
     nothingToDo = "Nothing to do..."
     openEntryList = "Open list of corresponding entries"
+    openEntryListNewTab = "Open in new tab"
     openLinkFailed = "Opening link '%s' failed!"
     winTitle = "PhysBiblio"
     winTitleModified = "PhysBiblio*"
@@ -59,6 +60,7 @@ class BibWindowsStrings(CommonStrings, CommonGUIStrings):
         cpAllPdf = "Copy all the corresponding PDF"
         cpBib = "bibtex(s)"
         cpCite = "\cite{key(s)}"
+        cpDir = "Name of the directory for associated files"
         cpKey = "key(s)"
         cpTit = "Copy to clipboard"
         eDesc = "--Entry: %s--"
@@ -70,6 +72,7 @@ class BibWindowsStrings(CommonStrings, CommonGUIStrings):
             "Warning: you can just add experiments to the selected entries, not delete!"
         )
         insCit = "Citation statistics"
+        insCitCo = "Update citation count"
         insCompl = "Complete info (ID and auxiliary info)"
         insComplTip = (
             "If the record has no associated INSPIRE ID,\n"
@@ -84,8 +87,10 @@ class BibWindowsStrings(CommonStrings, CommonGUIStrings):
         lnIns = "Open into INSPIRE-HEP"
         lnTit = "Links"
         maAdd = "Mark as '%s'"
+        maAddL = "Mark all as '%s'"
         maInv = "Invalid mark: '%s'"
         maRem = "Unmark as '%s'"
+        maRemL = "Unmark all as '%s'"
         maTit = "Marks"
         maUpd = "updateMark: '%s', entries: %s"
         notFoundFor = "KeyError: '%s' not found for '%s'"
@@ -113,8 +118,10 @@ class BibWindowsStrings(CommonStrings, CommonGUIStrings):
         selCat = "Select categories"
         selExp = "Select experiments"
         tyAdd = "Set '%s'"
+        tyAddL = "Set '%s' for all"
         tyInv = "Invalid type: '%s'"
         tyRem = "Unset '%s'"
+        tyRemL = "Unset '%s' for all"
         tyTit = "Type"
 
     class ED:
@@ -132,6 +139,8 @@ class BibWindowsStrings(CommonStrings, CommonGUIStrings):
 
         author = "<b>%s</b>"
         cats = "Categories: <i>%s</i>"
+        citIns = "Last citation count obtained from INSPIRE: %s"
+        citNoSelf = " (%s excluding self citations)"
         comm = "<br/>Comments:<br/>%s"
         exps = "Experiments: <i>%s</i>"
         keyErr = "KeyError: '%s' not in %s"
@@ -211,6 +220,7 @@ class BibWindowsStrings(CommonStrings, CommonGUIStrings):
     mergeBibs = "Merge bibtex entries"
     missMarks = "missing key: 'marks' in %s"
     newKey = "New bibtex key (%s) for element '%s'..."
+    newTab = "Open results in new tab"
     noModif = "No modifications to bibtex entry"
     noPDF = "no PDF"
     parseBibErr = "Problem in parsing the following bibtex code:\n%s"
@@ -397,6 +407,11 @@ class MainWindowStrings(CommonStrings, ErrorsStrings, CommonGUIStrings):
         catT = "&Categories"
         catND = "New Category"
         catNT = "Ne&w Category"
+        ccD = (
+            "Update the citation count of all bibtexs, "
+            + "using information from INSPIRE"
+        )
+        ccT = "Update citation count"
         chaD = "Show recent changes"
         chaT = "&Changelog"
         cleBD = "Clean all the bibtexs"
@@ -525,6 +540,7 @@ class MainWindowStrings(CommonStrings, ErrorsStrings, CommonGUIStrings):
         "These are the bibtex keys corresponding to invalid records:\n%s"
         + "\n\nNo action will be performed."
     )
+    citCount = "Citation Count"
     cleBib = "Clean Bibtexs"
     cleBibStart = "Starting cleaning of bibtexs..."
     cleBibStartAsk = (
