@@ -4,6 +4,9 @@ from .common import CommonStrings
 class ArgParserStrings:
     """Strings for the physbiblio.argParser module"""
 
+    citHelp = (
+        "update citation counts for all entries using info from the INSPIRE database"
+    )
     cleanHelp = "clean the entries in the database"
     cleanStartHelp = "the index from which the cleaning should start"
     cliHelp = "open the internal command line interface"
@@ -70,6 +73,10 @@ class ConfigStrings:
 
         ADSToken = "Token for connecting to the ADS service by NASA"
         autoResize = "Automatically resize columns and rows in the main bibtex table"
+        batchSizeInspire = (
+            "Batch size for cumulative searches through the INSPIRE API "
+            + "(it must be <= 1000)"
+        )
         bibListCols = "The columns to be shown in the entries list"
         confirmExit = "Confirm before exiting"
         defaultCat = "Default categories for imported bibtexs"
@@ -166,7 +173,7 @@ class DatabaseCoreStrings:
     errorInsUpd = "Cannot insert/update: ID exists!\n%s\nquery: %s"
     errorLiteralEval = "Error in literal_eval with string '%s'"
     invalidIsLocked = "Invalid `self.onIsLocked`!"
-    newColEntries = "New column in table 'entries': 'bibdict' (text)."
+    newColEntries = "New column in table 'entries': '%s' (%s)."
     noDatabaseCreate = "-------New database or missing tables.\nCreating them!\n\n"
     openDb = "Opening database: %s"
     opErDbOpen = (
@@ -192,6 +199,13 @@ class DatabaseStrings(CommonStrings, DatabaseCoreStrings):
         """Strings for the physbiblio.database. class"""
 
         alreadyExisting = "Already existing: %s\n"
+        apiChanged = "%d changed entries:\n%s"
+        apiDone = "Inspire OAI harvesting done!"
+        apiInfoS = "-- %s, '%s' -> '%s'"
+        apiInfoL = "-- %s"
+        apiInfoP = "Processing: %s"
+        apiNew = "new:\n%s"
+        apiOld = "old:\n%s"
         book = "Book"
         callOAIDates = "Calling INSPIRE-HEP OAI harvester between dates %s and %s"
         cannotParse = "Cannot parse properly:\n%s"
@@ -202,6 +216,15 @@ class DatabaseStrings(CommonStrings, DatabaseCoreStrings):
         cbResChan = "%d bibtex entries changed"
         cbResEntr = "%d entries processed"
         cbResErr = "%d errors occurred"
+        ccCannotReadId = (
+            "Cannot read the INSPIRE ID from the recently retrieved record %s"
+        )
+        ccCannotUpdateFields = (
+            "Cannot update citation fields for entry %s from record %s"
+        )
+        ccNoCorrespondence = "No correspondence in database for INSPIRE ID %s"
+        ccProcessTot = "CitationCount will process %d total entries"
+        ccProcessProgr = "%5d / %d (%5.2f%%) - citation count: '%s'"
         delete = "Delete entry, using key = '%s'"
         elementChanged = "-- element changed!"
         elementsFound = "%d elements found"
@@ -210,6 +233,7 @@ class DatabaseStrings(CommonStrings, DatabaseCoreStrings):
         errorGFNoElement = "Error in getField('%s', '%s'): no element found?"
         errorGFNoField = "Error in getField('%s', '%s'): the field is missing?"
         errorOAIEntryDet = "something wrong with entry %s\n%s"
+        errorOAIEntryMisKey = "Key %s missing for entry:\n%s"
         errorOAIEntryG = "Something went wrong with this entry..."
         errorParseBibtex = "Problem in parsing the following bibtex code:\n%s"
         errorParseBib = "Impossible to parse bibtex!"
@@ -282,12 +306,7 @@ class DatabaseStrings(CommonStrings, DatabaseCoreStrings):
         laiProcessTot = "LoadAndInsert will process %d total entries"
         laiReadError = "Error while reading the bibtex '%s'"
         lecture = "Lecture"
-        oaiChanged = "%d changed entries:\n%s"
-        oaiDone = "Inspire OAI harvesting done!"
-        oaiInfoS = "-- %s, '%s' -> '%s'"
-        oaiInfoL = "-- %s"
-        oaiOld = "old:\n%s"
-        oaiNew = "new:\n%s"
+        noneType = "No type"
         pabFound = "%d bibtex entries found."
         pabProgr = "%4d - %s\n"
         pabRead = "Reading bibtex entry #%d"
@@ -310,12 +329,14 @@ class DatabaseStrings(CommonStrings, DatabaseCoreStrings):
             + "Possibly the bibtex key has been changed "
             + "while processing entry '%s'?"
         )
+        souFirst = "Starting preliminary loop"
         souInvalidStart = "Invalid startFrom in searchOAIUpdates"
         souResChan = "%d entries changed"
         souResErr = "%d errors occurred"
         souResProc = "%d entries processed"
         souProcessProgr = "%5d / %d (%5.2f%%) - looking for update: '%s'"
         souProcessTot = "SearchOAIUpdates will process %d total entries"
+        souSecond = "Starting main loop"
         updateBibkey = "Updating bibkey for entry '%s' into '%s'"
         updateField = "Updating '%s' for entry '%s'"
         useQueryVals = "Using query:\n%s\nvalues: %s"
@@ -547,6 +568,8 @@ class TablesDefStrings:
         "marks": "Mark the record",
         "abstract": "Abstract of the record",
         "bibdict": "Dictionary with fields of the bibtex entry from bibtexparser",
+        "citations": "Most recent number of citations from INSPIRE",
+        "citations_no_self": "Most recent number of citations from INSPIRE, excluding self cites",
     }
     entriesExpsDescs = {
         "idEnEx": "Unique identifier",
