@@ -21,7 +21,11 @@ class ADSNasaStrings:
 class ArxivStrings(GenericStrings):
     """Strings for the arxiv module"""
 
+    cannotFindEntriesInFeed = "Key 'entries' not found in processed feed:\n%s"
     cannotParseRSS = "Cannot parse arxiv RSS feed:\n%s"
+    cannotReadDict = "Something went wrong when reading the dictionary"
+    cannotReadEntryId = "Cannot read the arXiv ID of this entry: %s"
+    cannotReadItem = "Something went wrong when reading the feed item"
     emptyUrl = "Url is empty!"
     errorYearConversion = "Error in converting year from '%s'"
     mainCatNotFound = "Main category not found: %s"
@@ -36,27 +40,26 @@ class DOIStrings(GenericStrings):
 class InspireStrings(GenericStrings):
     """Strings for the inspire module"""
 
+    apiResponseError = (
+        "An error occurred. The API returned the following message: %s - %s"
+    )
+    endString = "END --- %s \n\n"
     errorEmptyText = "An error occurred. Empty text obtained"
+    errorEmptySearch = "An error occurred. No search results obtained"
+    errorInvalidBibtex = "Invalid bibtex!\n%s"
+    errorReadRecord = "Error in readRecord! id:%s"
+    errorUpdateBibtex = "Cannot update bibtex!"
+    exceptionFormat = "%s, %s\n%s"
     foundID = "Found: %s"
     jsonError = "Cannot load JSON content"
-    searchIDInfo = "Search ID of %s -> %s"
-
-
-class InspireOAIStrings(GenericStrings):
-    """Strings for the inspireoai module"""
-
-    cannotSearch = "Inspireoai cannot search strings in the DB"
-    emptyRecord = "Empty record!"
-    endString = "END --- %s \n\n"
-    errorInvalidBibtex = "Invalid bibtex!\n%s"
-    errorReadRecord = "Error in readRecord!"
-    errorMarcxml = "Impossible to get marcxml for entry %s"
-    exceptionFormat = "%s, %s\n%s"
+    numberOfEntriesChanged = "The number of records changed from %s to %s during the execution of the INSPIRE API query"
     processed = "Processed %d elements"
     readData = "Reading data --- "
-    startString = "\nSTARTING OAI harvester --- %s \n\n"
+    searchIDInfo = "Search ID of %s -> %s"
+    searchResultsFrom = "Search info from %s"
+    startString = "\nSTARTING INSPIRE API harvester --- %s \n\n"
     warningJournal = "'journal' from OAI is missing or not a string (recid:%s)"
-    warningMissing = "Something from OAI is missing (recid:%s)"
+    warningMissingField = "Field '%s' from OAI is missing (recid:%s)"
 
 
 class ISBNStrings(GenericStrings):
