@@ -34,6 +34,10 @@ except Exception:
     print(traceback.format_exc())
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.exception")
 class TestParser(unittest.TestCase):
     """Tests for main parser and stuff"""
 
@@ -55,7 +59,7 @@ class TestParser(unittest.TestCase):
         for text in expected_output:
             self.assertIn(text, string)
 
-    def test_global(self):
+    def test_global(self, *args):
         """Test that the options are recognised correctly"""
         parser = setParser()
         for opt in ["-v", "--version"]:
@@ -78,7 +82,7 @@ class TestParser(unittest.TestCase):
                 lambda: parser.parse_args([opt]),
                 [
                     "usage: PhysBiblio.exe [-h] [-p ",
-                    "{clean,cli,daily,dates,export,test,tex,update,weekly,gui}",
+                    "{citations,clean,cli,daily,dates,export,test,tex,update,weekly,gui}",
                 ],
             )
         for opt in ["-p", "--profile"]:
@@ -94,10 +98,14 @@ class TestParser(unittest.TestCase):
                 args.func(args)
                 mock.assert_called_once_with()
 
-    def test_subcommands_ok(self):
+    def test_subcommands_ok(self, *args):
         """Test that the options are recognised correctly"""
         parser = setParser()
-        tests = [["gui", call_gui], ["test", call_tests]]
+        tests = [
+            ["citations", call_citationCount],
+            ["gui", call_gui],
+            ["test", call_tests],
+        ]
         for sub, func in tests:
             args = parser.parse_args([sub])
             self.assertIs(args.func, func)
@@ -398,7 +406,7 @@ class TestParser(unittest.TestCase):
                     args.func(args)
                     mock.assert_called_once_with(*expected[0], **expected[1])
 
-    def test_subcommands_fail(self):
+    def test_subcommands_fail(self, *args):
         """Test that the options are recognised correctly."""
         parser = setParser()
         tests = [
@@ -427,7 +435,7 @@ class TestParser(unittest.TestCase):
                 with self.assertRaises(SystemExit):
                     args = parser.parse_args([sub] + options)
 
-    def test_subcommand_tests(self):
+    def test_subcommand_tests(self, *args):
         """Test that the options are recognised correctly"""
         from physbiblio.setuptests import skipTestsSettings
 
@@ -438,19 +446,18 @@ class TestParser(unittest.TestCase):
         oldSettings = skipTestsSettings.copy()
         parser = setParser()
         tests = [
-            [["test"], False, False, False, False, False],
-            [["test", "-d"], True, False, False, False, False],
-            [["test", "--database"], True, False, False, False, False],
-            [["test", "-g"], False, True, False, False, False],
-            [["test", "--gui"], False, True, False, False, False],
-            [["test", "-l"], False, False, True, False, False],
-            [["test", "--long"], False, False, True, False, False],
-            [["test", "-o"], False, False, False, True, True],
-            [["test", "--online"], False, False, False, True, True],
-            [["test", "--online_oai"], False, False, False, True, False],
-            [["test", "-d", "--online"], True, False, False, True, True],
+            [["test"], False, False, False, False],
+            [["test", "-d"], True, False, False, False],
+            [["test", "--database"], True, False, False, False],
+            [["test", "-g"], False, True, False, False],
+            [["test", "--gui"], False, True, False, False],
+            [["test", "-l"], False, False, True, False],
+            [["test", "--long"], False, False, True, False],
+            [["test", "-o"], False, False, False, True],
+            [["test", "--online"], False, False, False, True],
+            [["test", "-d", "--online"], True, False, False, True],
         ]
-        for options, _db, _gui, _lon, _oai, _onl in tests:
+        for options, _db, _gui, _lon, _onl in tests:
             skipTestsSettings.default()
             with patch(patchString, autospec=True) as _run:
                 args = parser.parse_args(options)
@@ -458,14 +465,121 @@ class TestParser(unittest.TestCase):
                 self.assertEqual(skipTestsSettings.db, _db)
                 self.assertEqual(skipTestsSettings.gui, _gui)
                 self.assertEqual(skipTestsSettings.long, _lon)
-                self.assertEqual(skipTestsSettings.oai, _oai)
                 self.assertEqual(skipTestsSettings.online, _onl)
                 self.assertEqual(_run.call_count, 1)
         with self.assertRaises(SystemExit):
             args = parser.parse_args(["test", "-a"])
         skipTestsSettings = oldSettings
 
-    def test_call_gui(self):
+    def test_call_citationCount(self, *args):
+        """test call_citationCount"""
+        with patch(
+            "physbiblio.database.Entries.getAll",
+            return_value=[{"inspire": "a"}, {"inspire": "b"}],
+        ) as _ga, patch("physbiblio.database.Entries.citationCount") as _cc, patch(
+            "physbiblio.databaseCore.PhysBiblioDBCore.commit"
+        ) as _c:
+            call_citationCount("args")
+            _ga.assert_called_once_with()
+            _cc.assert_called_once_with(["a", "b"])
+            _c.assert_called_once_with()
+
+    def test_call_clean(self, *args):
+        """test call_clean"""
+        args = NameSpace()
+        args.startFrom = 12
+        with patch("physbiblio.database.Entries.cleanBibtexs") as _f, patch(
+            "physbiblio.databaseCore.PhysBiblioDBCore.commit"
+        ) as _c:
+            call_clean(args)
+            _f.assert_called_once_with(startFrom=12)
+            _c.assert_called_once_with()
+
+    def test_call_cli(self, *args):
+        """test call_cli"""
+        with patch("physbiblio.cli.cli") as _f:
+            call_cli(args)
+            _f.assert_called_once_with()
+
+    def test_call_export(self, *args):
+        """test call_export"""
+        args = NameSpace()
+        args.filename = "abc"
+        with patch("physbiblio.export.PBExport.exportAll") as _f:
+            call_export(args)
+            _f.assert_called_once_with("abc")
+
+    def test_call_tex(self, *args):
+        """test call_tex"""
+        args = NameSpace()
+        args.texFiles = ["a", "b", "c"]
+        args.bibFile = "bib"
+        args.overwrite = "o"
+        args.save = "s"
+        args.updateExisting = "u"
+        args.removeUnused = "r"
+        args.reorder = "d"
+        with patch("physbiblio.export.PBExport.exportForTexFile") as _f:
+            call_tex(args)
+            _f.assert_called_once_with(
+                ["a", "b", "c"],
+                "bib",
+                overwrite="o",
+                autosave="s",
+                updateExisting="u",
+                removeUnused="r",
+                reorder="d",
+            )
+
+    def test_call_update(self, *args):
+        """test call_update"""
+        args = NameSpace()
+        args.startFrom = 12
+        args.force = "f"
+        with patch("physbiblio.database.Entries.searchOAIUpdates") as _f, patch(
+            "physbiblio.databaseCore.PhysBiblioDBCore.commit"
+        ) as _c:
+            call_update(args)
+            _f.assert_called_once_with(startFrom=12, force="f")
+            _c.assert_called_once_with()
+
+    def test_cumulativeInspireDates(self, *args):
+        """test cumulativeInspireDates"""
+        with patch("physbiblio.database.Entries.getDailyInfoFromOAI") as _f, patch(
+            "physbiblio.databaseCore.PhysBiblioDBCore.commit"
+        ) as _c:
+            cumulativeInspireDates("a", "b")
+            _f.assert_called_once_with("a", "b")
+            _c.assert_called_once_with()
+
+    def test_call_dates(self, *args):
+        """test call_dates"""
+        args = NameSpace()
+        args.start = "s"
+        args.end = "e"
+        with patch("physbiblio.argParser.cumulativeInspireDates") as _f:
+            call_dates(args)
+            _f.assert_called_once_with("s", "e")
+
+    def test_call_daily(self, *args):
+        """test call_daily"""
+        with patch("physbiblio.argParser.cumulativeInspireDates") as _f:
+            call_daily("args")
+            _f.assert_called_once_with(
+                (datetime.date.today() - datetime.timedelta(1)).strftime("%Y-%m-%d"),
+                datetime.date.today().strftime("%Y-%m-%d"),
+            )
+
+    def test_call_weekly(self, *args):
+        """test call_weekly"""
+        with patch("physbiblio.argParser.cumulativeInspireDates") as _f:
+            call_weekly("args")
+            _f.assert_called_once_with(
+                (datetime.date.today() - datetime.timedelta(7)).strftime("%Y-%m-%d"),
+                datetime.date.today().strftime("%Y-%m-%d"),
+            )
+
+    def test_call_gui(self, *args):
         """test the call_gui function"""
         mw = MainWindow()
         mw.show = MagicMock()
