@@ -34,6 +34,7 @@ try:
         ignoreParameterOrder,
         loggingLevels,
         pbConfig,
+        replacePBDATA,
     )
     from physbiblio.databaseCore import PhysBiblioDBCore, PhysBiblioDBSub
     from physbiblio.setuptests import *
@@ -50,10 +51,15 @@ tempCfgName1 = os.path.join(pbConfig.dataPath, "tests_cfg1_%s.db" % today_ymd)
 tempProfName = os.path.join(pbConfig.dataPath, "tests_prof_%s.db" % today_ymd)
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestConfigParameter(unittest.TestCase):
     """Tests for ConfigParameter from physbiblio.config"""
 
-    def test_init(self):
+    def test_init(self, *args):
         """Test __init__"""
         p = ConfigParameter(
             "name", "abc", description="desc", special="int", isGlobal=True
@@ -70,7 +76,7 @@ class TestConfigParameter(unittest.TestCase):
         self.assertEqual(p.special, None)
         self.assertEqual(p.isGlobal, False)
 
-    def test_getitem(self):
+    def test_getitem(self, *args):
         """test __getitem__"""
         p = ConfigParameter(
             "name", "abc", description="desc", special="int", isGlobal=True
@@ -87,15 +93,20 @@ class TestConfigParameter(unittest.TestCase):
             )
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestConfigParametersList(unittest.TestCase):
     """Tests for ConfigParametersList from physbiblio.config"""
 
-    def test_init(self):
+    def test_init(self, *args):
         """Test __init__"""
         p = ConfigParametersList()
         self.assertIsInstance(p, OrderedDict)
 
-    def test_add(self):
+    def test_add(self, *args):
         """Test add"""
         pl = ConfigParametersList()
         p1 = ConfigParameter("name", "abc")
@@ -107,10 +118,15 @@ class TestConfigParametersList(unittest.TestCase):
         self.assertEqual(list(pl.keys()), ["name", "other"])
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestConfigGlobals(unittest.TestCase):
     """Tests for global variables in physbiblio.config"""
 
-    def test_config(self):
+    def test_config(self, *args):
         """test global variables"""
         import physbiblio.config as pbc
 
@@ -121,10 +137,15 @@ class TestConfigGlobals(unittest.TestCase):
         self.assertIsInstance(pbc.pbConfig, ConfigVars)
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestConfigMethods(unittest.TestCase):
     """Tests for methods in physbiblio.config"""
 
-    def test_config(self):
+    def test_config(self, *args):
         """Test config methods for config management"""
         if os.path.exists(tempCfgName):
             os.remove(tempCfgName)
@@ -200,7 +221,7 @@ class TestConfigMethods(unittest.TestCase):
         os.remove(tempCfgName)
         os.remove(tempOldCfgName)
 
-    def test_profiles(self):
+    def test_profiles(self, *args):
         """Test config methods for profiles management"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -358,7 +379,7 @@ class TestConfigMethods(unittest.TestCase):
         if os.path.exists(tempProfName2):
             os.remove(tempProfName2)
 
-    def test_searches(self):
+    def test_searches(self, *args):
         """Test config methods for profiles management"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -514,10 +535,15 @@ class TestConfigMethods(unittest.TestCase):
             self.assertEqual(tempPbConfig.globalDb.countSearches(), 0)
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestGlobalDBOperations(unittest.TestCase):
     """Test GlobalDB"""
 
-    def test_operations(self):
+    def test_operations(self, *args):
         """Test database for profiles"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -595,12 +621,9 @@ class TestGlobalDBOperations(unittest.TestCase):
                     "name": u"default",
                     "description": u"newsomething",
                     "databasefile": str(
-                        os.path.join(
-                            pbConfig.dataPath,
-                            configuration_params["mainDatabaseName"].default.replace(
-                                "PBDATA", ""
-                            ),
-                        )
+                        configuration_params["mainDatabaseName"]
+                        .default.replace("PBDATA", "")
+                        .replace(pbConfig.dataPath, "")
                     ),
                     "oldCfg": u"",
                     "isDefault": 1,
@@ -672,6 +695,11 @@ class TestGlobalDBOperations(unittest.TestCase):
         self.assertEqual(self.globalDb.getDefaultProfile(), "default")
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestGlobalDB(unittest.TestCase):
     """Test GlobalDB"""
 
@@ -693,7 +721,7 @@ class TestGlobalDB(unittest.TestCase):
         """restore curs"""
         self.globalDb.curs = self.origcurs
 
-    def test_init(self):
+    def test_init(self, *args):
         """test __init__"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -742,7 +770,7 @@ class TestGlobalDB(unittest.TestCase):
         self.assertIsInstance(globalDb.config, ConfigurationDB)
         self.assertEqual(globalDb.dataPath, pbConfig.dataPath)
 
-    def test_createTables(self):
+    def test_createTables(self, *args):
         """test createTables"""
         with patch("physbiblio.config.GlobalDB.createTable", autospec=True) as _ct:
             self.globalDb.createTables(["profiles", "searches"])
@@ -756,14 +784,14 @@ class TestGlobalDB(unittest.TestCase):
                 self.globalDb, "profiles", profilesSettingsTable, critical=True
             )
 
-    def test_countProfiles(self):
+    def test_countProfiles(self, *args):
         """test countProfiles"""
         self.globalDb.curs.fetchall = MagicMock(return_value=[[12]])
         with patch("physbiblio.config.GlobalDB.cursExec", autospec=True) as _ct:
             self.assertEqual(self.globalDb.countProfiles(), 12)
             _ct.assert_called_once_with(self.globalDb, "SELECT Count(*) FROM profiles")
 
-    def test_createProfile(self):
+    def test_createProfile(self, *args):
         """test createProfile"""
         cmd = (
             "INSERT into profiles "
@@ -786,8 +814,7 @@ class TestGlobalDB(unittest.TestCase):
             data = {
                 "name": "default",
                 "description": "",
-                "databasefile": os.path.join(
-                    self.globalDb.dataPath,
+                "databasefile": (
                     configuration_params["mainDatabaseName"].default.replace(
                         "PBDATA", ""
                     ),
@@ -816,7 +843,7 @@ class TestGlobalDB(unittest.TestCase):
             _ex.assert_called_once_with("Cannot insert profile")
             _se.assert_called_once_with(1)
 
-    def test_updateProfileField(self):
+    def test_updateProfileField(self, *args):
         """test updateProfileField"""
         with patch("logging.Logger.error") as _e:
             self.assertFalse(
@@ -869,7 +896,7 @@ class TestGlobalDB(unittest.TestCase):
             self.assertTrue(self.globalDb.updateProfileField(1, "databasefile", "new"))
             _co.assert_called_once_with(self.globalDb, verbose=False)
 
-    def test_deleteProfile(self):
+    def test_deleteProfile(self, *args):
         """test deleteProfile"""
         with patch("logging.Logger.error") as _e:
             self.assertFalse(self.globalDb.deleteProfile(""))
@@ -903,7 +930,7 @@ class TestGlobalDB(unittest.TestCase):
             self.assertTrue(self.globalDb.deleteProfile("a"))
             self.assertEqual(_gd.call_count, 4)
 
-    def test_getProfiles(self):
+    def test_getProfiles(self, *args):
         """test getProfiles"""
         self.globalDb.curs.fetchall = MagicMock(return_value=[[12]])
         with patch("physbiblio.config.GlobalDB.cursExec", autospec=True) as _ct:
@@ -912,7 +939,7 @@ class TestGlobalDB(unittest.TestCase):
                 self.globalDb, "SELECT * FROM profiles order by ord ASC, name ASC\n"
             )
 
-    def test_getProfile(self):
+    def test_getProfile(self, *args):
         """test getProfile"""
         with patch("logging.Logger.warning") as _w:
             self.assertEqual(self.globalDb.getProfile(), {})
@@ -940,7 +967,7 @@ class TestGlobalDB(unittest.TestCase):
                 {"name": "", "file": "a"},
             )
 
-    def test_getProfileOrder(self):
+    def test_getProfileOrder(self, *args):
         """test getProfileOrder"""
         self.globalDb.curs.fetchall = MagicMock(
             return_value=[{"name": "a"}, {"name": "b"}]
@@ -965,7 +992,7 @@ class TestGlobalDB(unittest.TestCase):
             _cp.assert_called_once_with(self.globalDb)
             _se.assert_called_once_with(self.globalDb, "default")
 
-    def test_setProfileOrder(self):
+    def test_setProfileOrder(self, *args):
         """test setProfileOrder"""
         with patch("logging.Logger.warning") as _w:
             self.assertFalse(self.globalDb.setProfileOrder())
@@ -1057,7 +1084,7 @@ class TestGlobalDB(unittest.TestCase):
             self.assertEqual(_e.call_count, 0)
             self.assertEqual(_u.call_count, 0)
 
-    def test_getDefaultProfile(self):
+    def test_getDefaultProfile(self, *args):
         """test getDefaultProfile"""
         self.globalDb.curs.fetchall = MagicMock(
             return_value=[{"name": "b"}, {"name": "a"}]
@@ -1095,7 +1122,7 @@ class TestGlobalDB(unittest.TestCase):
             _se.assert_any_call(self.globalDb, "c")
             _i.assert_called_once_with("Default profile changed to %s" % "c")
 
-    def test_setDefaultProfile(self):
+    def test_setDefaultProfile(self, *args):
         """test setDefaultProfile"""
         with patch("logging.Logger.warning") as _w:
             self.assertFalse(self.globalDb.setDefaultProfile())
@@ -1149,14 +1176,14 @@ class TestGlobalDB(unittest.TestCase):
             self.assertEqual(_e.call_count, 2)
             self.assertEqual(_u.call_count, 2)
 
-    def test_countSearches(self):
+    def test_countSearches(self, *args):
         """test countSearches"""
         self.globalDb.curs.fetchall = MagicMock(return_value=[[12]])
         with patch("physbiblio.config.GlobalDB.cursExec", autospec=True) as _ct:
             self.assertEqual(self.globalDb.countSearches(), 12)
             _ct.assert_called_once_with(self.globalDb, "SELECT Count(*) FROM searches")
 
-    def test_insertSearch(self):
+    def test_insertSearch(self, *args):
         """test insertSearch"""
         with patch(
             "physbiblio.config.GlobalDB.connExec",
@@ -1212,7 +1239,7 @@ class TestGlobalDB(unittest.TestCase):
                 },
             )
 
-    def test_deleteSearch(self):
+    def test_deleteSearch(self, *args):
         """test deleteSearch"""
         with patch(
             "physbiblio.config.GlobalDB.cursExec", autospec=True, return_value="abcd"
@@ -1223,7 +1250,7 @@ class TestGlobalDB(unittest.TestCase):
             )
             _co.assert_called_once_with(self.globalDb)
 
-    def test_getAllSearches(self):
+    def test_getAllSearches(self, *args):
         """test getAllSearches"""
         self.globalDb.curs.fetchall = MagicMock(return_value=[[12]])
         with patch("physbiblio.config.GlobalDB.cursExec", autospec=True) as _ct:
@@ -1232,7 +1259,7 @@ class TestGlobalDB(unittest.TestCase):
                 self.globalDb, "select * from searches order by count asc\n"
             )
 
-    def test_getSearchByID(self):
+    def test_getSearchByID(self, *args):
         """test getSearchByID"""
         self.globalDb.curs.fetchall = MagicMock(return_value=[[12]])
         with patch("physbiblio.config.GlobalDB.cursExec", autospec=True) as _ct:
@@ -1241,7 +1268,7 @@ class TestGlobalDB(unittest.TestCase):
                 self.globalDb, "select * from searches where idS=?\n", (123,)
             )
 
-    def test_getSearchByName(self):
+    def test_getSearchByName(self, *args):
         """test getSearchByName"""
         self.globalDb.curs.fetchall = MagicMock(return_value=[[12]])
         with patch("physbiblio.config.GlobalDB.cursExec", autospec=True) as _ct:
@@ -1250,7 +1277,7 @@ class TestGlobalDB(unittest.TestCase):
                 self.globalDb, "select * from searches where name=?\n", ("abc",)
             )
 
-    def test_getSearchList(self):
+    def test_getSearchList(self, *args):
         """test getSearchList"""
         self.globalDb.curs.fetchall = MagicMock(return_value=[[12]])
         with patch("physbiblio.config.GlobalDB.cursExec", autospec=True) as _ct:
@@ -1280,7 +1307,7 @@ class TestGlobalDB(unittest.TestCase):
                 (0, 0),
             )
 
-    def test_updateSearchOrder(self):
+    def test_updateSearchOrder(self, *args):
         """test updateSearchOrder"""
         self.globalDb.curs.fetchall = MagicMock(
             return_value=[
@@ -1349,7 +1376,7 @@ class TestGlobalDB(unittest.TestCase):
             )
             _d.assert_called_once_with(self.globalDb, 14)
 
-    def test_updateSearchField(self):
+    def test_updateSearchField(self, *args):
         """test updateSearchField"""
         with patch("logging.Logger.warning") as _w:
             self.assertFalse(self.globalDb.updateSearchField(1, "test", "abc"))
@@ -1380,10 +1407,15 @@ class TestGlobalDB(unittest.TestCase):
 
 
 @unittest.skipIf(skipTestsSettings.db, "Database tests")
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestConfigurationDBOperations(DBTestCase):
     """Test ConfigurationDB"""
 
-    def test_operations(self):
+    def test_operations(self, *args):
         """Test count, insert and update, delete and get methods"""
         self.assertIsInstance(self.pBDB.config, ConfigurationDB)
         self.assertIsInstance(self.pBDB.config, PhysBiblioDBSub)
@@ -1417,6 +1449,11 @@ class TestConfigurationDBOperations(DBTestCase):
 
 
 @unittest.skipIf(skipTestsSettings.db, "Database tests")
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestConfigurationDB(DBTestCase):
     """Test ConfigurationDB"""
 
@@ -1429,7 +1466,7 @@ class TestConfigurationDB(DBTestCase):
         """restore curs"""
         self.pBDB.config.curs = self.origcurs
 
-    def test_count(self):
+    def test_count(self, *args):
         """test count"""
         self.pBDB.config.curs.fetchall = MagicMock(return_value=[[12]])
         with patch(
@@ -1440,7 +1477,7 @@ class TestConfigurationDB(DBTestCase):
                 self.pBDB.config, "SELECT Count(*) FROM settings"
             )
 
-    def test_insert(self):
+    def test_insert(self, *args):
         """test insert"""
         self.pBDB.config.curs.fetchall = MagicMock(return_value=[[12]])
         with patch(
@@ -1475,7 +1512,7 @@ class TestConfigurationDB(DBTestCase):
                 {"name": "abc", "value": "def"},
             )
 
-    def test_update(self):
+    def test_update(self, *args):
         """test update"""
         self.pBDB.config.curs.fetchall = MagicMock(return_value=[])
         with patch(
@@ -1510,7 +1547,7 @@ class TestConfigurationDB(DBTestCase):
                 {"name": "abc", "value": "def"},
             )
 
-    def test_delete(self):
+    def test_delete(self, *args):
         """test delete"""
         with patch(
             "physbiblio.databaseCore.PhysBiblioDBSub.cursExec",
@@ -1522,7 +1559,7 @@ class TestConfigurationDB(DBTestCase):
                 self.pBDB.config, "delete from settings where name=?\n", ("abc",)
             )
 
-    def test_getAll(self):
+    def test_getAll(self, *args):
         """test getAll"""
         self.pBDB.config.curs.fetchall = MagicMock(return_value=[[12]])
         with patch(
@@ -1531,7 +1568,7 @@ class TestConfigurationDB(DBTestCase):
             self.assertEqual(self.pBDB.config.getAll(), [[12]])
             _cu.assert_called_once_with(self.pBDB.config, "select * from settings\n")
 
-    def test_getByName(self):
+    def test_getByName(self, *args):
         """test getByName"""
         self.pBDB.config.curs.fetchall = MagicMock(return_value=[[12]])
         with patch(
@@ -1543,10 +1580,15 @@ class TestConfigurationDB(DBTestCase):
             )
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestConfigVars(unittest.TestCase):
     """Tests for ConfigVars"""
 
-    def test_init(self):
+    def test_init(self, *args):
         """test __init__"""
         self.assertTrue(hasattr(ConfigVars, "adsUrl"))
         self.assertTrue(hasattr(ConfigVars, "arxivUrl"))
@@ -1556,7 +1598,6 @@ class TestConfigVars(unittest.TestCase):
         self.assertTrue(hasattr(ConfigVars, "inspireExperimentsLink"))
         self.assertTrue(hasattr(ConfigVars, "inspireLiteratureAPI"))
         self.assertTrue(hasattr(ConfigVars, "inspireLiteratureLink"))
-        self.assertTrue(hasattr(ConfigVars, "inspireOAI"))
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
         with patch("logging.Logger.info") as _i, patch(
@@ -1626,7 +1667,7 @@ class TestConfigVars(unittest.TestCase):
         self.assertIsInstance(cv.params, dict)
         self.assertEqual(len(cv.params), len(configuration_params) - 1)
 
-    def test_loadProfiles(self):
+    def test_loadProfiles(self, *args):
         """test loadProfiles"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -1648,7 +1689,7 @@ class TestConfigVars(unittest.TestCase):
                 _w.assert_called_once()
                 _cp.assert_called_once_with(cv.globalDb)
 
-    def test_prepareLogger(self):
+    def test_prepareLogger(self, *args):
         """test prepareLogger"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -1659,7 +1700,7 @@ class TestConfigVars(unittest.TestCase):
             _gl.assert_called_once_with("abcd")
         self.assertEqual(cv.loggerString, "abcd")
 
-    def test_readConfig(self):
+    def test_readConfig(self, *args):
         """test readConfig"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -1689,7 +1730,9 @@ class TestConfigVars(unittest.TestCase):
             _dbc.assert_called_once_with(cv.currentDatabase, cv.logger, info=False)
             _cdb.assert_called_once_with(tempDb)
             _rp.assert_has_calls([call(cv, k, configDb) for k in configuration_params])
-            _afh.assert_called_once_with(cv.logger, cv.params["logFileName"])
+            _afh.assert_called_once_with(
+                cv.logger, cv.params["logFileName"], defaultPath=cv.dataPath
+            )
             tempDb.closeDB.assert_called_once_with(info=False)
         with patch("logging.Logger.debug") as _d, patch(
             "logging.Logger.exception"
@@ -1747,7 +1790,7 @@ class TestConfigVars(unittest.TestCase):
                 cv, list(configuration_params.keys())[0], configDb
             )
 
-    def test_readParam(self):
+    def test_readParam(self, *args):
         """test readConfig"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -1890,7 +1933,7 @@ class TestConfigVars(unittest.TestCase):
             self.assertEqual(_w.call_count, 0)
         self.assertEqual(cv.params[key], os.path.join(cv.dataPath, "local"))
 
-    def test_readProfiles(self):
+    def test_readProfiles(self, *args):
         """test readProfiles"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -1921,11 +1964,19 @@ class TestConfigVars(unittest.TestCase):
             _go.assert_called_once_with(cv.globalDb)
             self.assertEqual(res[0], "def")
             self.assertEqual(
-                res[1], {"a": {"n": "a", "d": "desc", "f": "no", "db": "test.db"}}
+                res[1],
+                {
+                    "a": {
+                        "n": "a",
+                        "d": "desc",
+                        "f": "no",
+                        "db": os.path.join(cv.dataPath, "test.db"),
+                    }
+                },
             )
             self.assertEqual(res[2], "ord")
 
-    def test_reInit(self):
+    def test_reInit(self, *args):
         """test reInit"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -1933,7 +1984,7 @@ class TestConfigVars(unittest.TestCase):
         cv.defaultProfileName = "b"
         cv.profiles = {
             "a": {"n": "a", "d": "desc", "f": "no", "db": "test.db"},
-            "b": {"n": "b", "d": "ript", "f": "si", "db": "tset.db"},
+            "b": {"n": "b", "d": "ript", "f": "si", "db": os.sep + "tset.db"},
         }
         with patch("logging.Logger.error") as _e, patch(
             "physbiblio.config.ConfigVars.readConfig", autospec=True
@@ -1956,7 +2007,9 @@ class TestConfigVars(unittest.TestCase):
             _i.assert_called_once()
         self.assertEqual(cv.currentProfileName, "a")
         self.assertEqual(cv.currentProfile, cv.profiles["a"])
-        self.assertEqual(cv.currentDatabase, cv.profiles["a"]["db"])
+        self.assertEqual(
+            cv.currentDatabase, os.path.join(cv.dataPath, cv.profiles["a"]["db"])
+        )
 
         with patch("logging.Logger.error") as _e, patch(
             "logging.Logger.info"
@@ -1974,7 +2027,7 @@ class TestConfigVars(unittest.TestCase):
         self.assertEqual(cv.currentProfile, cv.profiles["b"])
         self.assertEqual(cv.currentDatabase, cv.profiles["b"]["db"])
 
-    def test_reloadProfiles(self):
+    def test_reloadProfiles(self, *args):
         """test reloadProfiles"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -2001,7 +2054,7 @@ class TestConfigVars(unittest.TestCase):
         cv.defaultProfileName = "b"
         cv.profiles = {
             "a": {"n": "a", "d": "desc", "f": "no", "db": "test.db"},
-            "b": {"n": "b", "d": "ript", "f": "si", "db": "tset.db"},
+            "b": {"n": "b", "d": "ript", "f": "si", "db": os.sep + "tset.db"},
         }
         with patch("logging.Logger.critical") as _c, patch(
             "logging.Logger.info"
@@ -2017,7 +2070,9 @@ class TestConfigVars(unittest.TestCase):
             _rc.assert_called_once_with(cv)
         self.assertEqual(cv.currentProfileName, "a")
         self.assertEqual(cv.currentProfile, cv.profiles["a"])
-        self.assertEqual(cv.currentDatabase, cv.profiles["a"]["db"])
+        self.assertEqual(
+            cv.currentDatabase, os.path.join(cv.dataPath, cv.profiles["a"]["db"])
+        )
 
         with patch("logging.Logger.critical") as _c, patch(
             "logging.Logger.info"
@@ -2035,7 +2090,7 @@ class TestConfigVars(unittest.TestCase):
         self.assertEqual(cv.currentProfile, cv.profiles["b"])
         self.assertEqual(cv.currentDatabase, cv.profiles["b"]["db"])
 
-    def test_replacePBDATA(self):
+    def test_replacePBDATA(self, *args):
         """test replacePBDATA"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -2046,7 +2101,13 @@ class TestConfigVars(unittest.TestCase):
             cv.replacePBDATA("PBDATAabcd"), os.path.join(cv.dataPath, "abcd")
         )
 
-    def test_setDefaultParams(self):
+        self.assertEqual(replacePBDATA("ab", 123), 123)
+        self.assertEqual(replacePBDATA("AB", "abcd"), "abcd")
+        self.assertEqual(
+            replacePBDATA("ABC", "PBDATAabcd"), os.path.join("ABC", "abcd")
+        )
+
+    def test_setDefaultParams(self, *args):
         """test setDefaultParams"""
         if os.path.exists(tempProfName):
             os.remove(tempProfName)
@@ -2066,10 +2127,15 @@ class TestConfigVars(unittest.TestCase):
                 self.assertEqual(cv.params[k], v)
 
 
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.error")
+@patch("logging.Logger.exception")
 class TestFunctions(unittest.TestCase):
     """Tests for more functions in config module"""
 
-    def test_getLogLevel(self):
+    def test_getLogLevel(self, *args):
         """test getLogLevel"""
         for v, e in [
             [0, logging.ERROR],
@@ -2080,7 +2146,7 @@ class TestFunctions(unittest.TestCase):
         ]:
             self.assertEqual(getLogLevel(v), e)
 
-    def test_addFileHandler(self):
+    def test_addFileHandler(self, *args):
         """test addFileHandler"""
         log = logging.Logger("testAFH")
         h = logging.handlers.RotatingFileHandler(pbConfig.overWritelogFileName)
@@ -2091,6 +2157,19 @@ class TestFunctions(unittest.TestCase):
             )
         self.assertEqual(h.level, getLogLevel(pbConfig.params["loggingLevel"]))
         self.assertIn(h, log.handlers)
+        log = logging.Logger("testAFH1")
+        with patch(
+            "physbiblio.config.replacePBDATA",
+            return_value=pbConfig.overWritelogFileName,
+        ) as _rfh:
+            addFileHandler(
+                log,
+                "/can/not/create/this/log/file/myfn.log",
+                defaultPath=pbConfig.dataPath,
+            )
+            _rfh.assert_called_once_with(
+                pbConfig.dataPath, configuration_params["logFileName"].default
+            )
 
 
 def tearDownModule():
