@@ -32,23 +32,21 @@ except Exception:
 
 
 @unittest.skipIf(skipTestsSettings.online, "Online tests")
+@patch("logging.Logger.debug")
+@patch("logging.Logger.info")
+@patch("logging.Logger.warning")
+@patch("logging.Logger.exception")
 class TestInspireStatsMethods(unittest.TestCase):
     """Tests for methods in physbiblio.inspireStats"""
 
-    def test_init(self):
+    def test_init(self, *args):
         """test some properties"""
         self.assertIsInstance(pBStats, InspireStatsLoader)
         tpBStats = InspireStatsLoader()
-        self.assertEqual(tpBStats.urlBase, pbConfig.inspireLiteratureAPI)
-        self.assertEqual(tpBStats.timeout, float(pbConfig.params["timeoutWebSearch"]))
-        self.assertEqual(tpBStats.authorStatsOpts, "&size=")
-        self.assertEqual(tpBStats.paperStatsOpts, "&size=")
-        self.assertEqual(tpBStats.skipPageOpt, "&page=")
-        self.assertEqual(tpBStats.maxPerPage, 250)
         self.assertEqual(tpBStats.authorPlotInfo, None)
         self.assertEqual(tpBStats.paperPlotInfo, None)
 
-    def test_paperStats(self):
+    def test_paperStats(self, *args):
         """Test paperStats function downloading real and fake data"""
         # not a valid record (it was cancelled):
         self.assertEqual(
@@ -93,8 +91,13 @@ class TestInspireStatsMethods(unittest.TestCase):
         pbm.assert_called_once_with(2)
         pbv.assert_has_calls([call(1), call(2)])
 
-    def test_authorStats(self):
+    def test_authorStats(self, *args):
         """Test paperStats function downloading real and fake data"""
+        res = pBStats.authorStats("E.M.Zavanin.1")
+        self.assertTrue(res["h"] >= 4)
+        self.assertTrue(res["paLi"][1][-1] == 8)
+        self.assertTrue(res["allLi"][1][-1] >= 320)
+        self.assertTrue(res["meanLi"][1][-1] >= 40)
         with patch(
             "physbiblio.inspireStats.InspireStatsLoader.paperStats",
             return_value={
@@ -162,12 +165,7 @@ class TestInspireStatsMethods(unittest.TestCase):
                 "1519902",
             ]:
                 self.assertIn(i, testGood["aI"].keys())
-            _mock.assert_has_calls(
-                [
-                    call(pBStats, i, paperDate=testGood["aI"][i]["date"], verbose=0)
-                    for i in sorted(testGood["aI"].keys())
-                ]
-            )
+                self.assertIn(i, [a[0][1] for a in _mock.call_args_list])
             self.assertTrue(
                 testGood.keys(), ["meanLi", "allLi", "aI", "paLi", "h", "name"]
             )
