@@ -25,18 +25,202 @@ except ImportError:
     raise
 
 
+arxivCategories = {
+    "astro-ph": ["CO", "EP", "GA", "HE", "IM", "SR"],
+    "cond-mat": [
+        "dis-nn",
+        "mes-hall",
+        "mtrl-sci",
+        "other",
+        "quant-gas",
+        "soft",
+        "stat-mech",
+        "str-el",
+        "supr-con",
+    ],
+    "cs": [
+        "AI",
+        "AR",
+        "CC",
+        "CE",
+        "CG",
+        "CL",
+        "CR",
+        "CV",
+        "CY",
+        "DB",
+        "DC",
+        "DL",
+        "DM",
+        "DS",
+        "ET",
+        "FL",
+        "GL",
+        "GR",
+        "GT",
+        "HC",
+        "IR",
+        "IT",
+        "LG",
+        "LO",
+        "MA",
+        "MM",
+        "MS",
+        "NA",
+        "NE",
+        "NI",
+        "OH",
+        "OS",
+        "PF",
+        "PL",
+        "RO",
+        "SC",
+        "SD",
+        "SE",
+        "SI",
+        "SY",
+    ],
+    "econ": ["EM", "GN", "TH"],
+    "eess": ["AS", "IV", "SP"],
+    "gr-qc": [],
+    "hep-ex": [],
+    "hep-lat": [],
+    "hep-ph": [],
+    "hep-th": [],
+    "math": [
+        "AC",
+        "AG",
+        "AP",
+        "AT",
+        "CA",
+        "CO",
+        "CT",
+        "CV",
+        "DG",
+        "DS",
+        "FA",
+        "GM",
+        "GN",
+        "GR",
+        "GT",
+        "HO",
+        "IT",
+        "KT",
+        "LO",
+        "MG",
+        "MP",
+        "NA",
+        "NT",
+        "OA",
+        "OC",
+        "PR",
+        "QA",
+        "RA",
+        "RT",
+        "SG",
+        "SP",
+        "ST",
+    ],
+    "math-ph": [],
+    "nlin": ["AO", "CD", "CG", "PS", "SI"],
+    "nucl-ex": [],
+    "nucl-th": [],
+    "physics": [
+        "acc-ph",
+        "ao-ph",
+        "app-ph",
+        "atm-clus",
+        "atom-ph",
+        "bio-ph",
+        "chem-ph",
+        "class-ph",
+        "comp-ph",
+        "data-an",
+        "ed-ph",
+        "flu-dyn",
+        "gen-ph",
+        "geo-ph",
+        "hist-ph",
+        "ins-det",
+        "med-ph",
+        "optics",
+        "plasm-ph",
+        "pop-ph",
+        "soc-ph",
+        "space-ph",
+    ],
+    "q-bio": ["BM", "CB", "GN", "MN", "NC", "OT", "PE", "QM", "SC", "TO"],
+    "q-fin": ["CP", "EC", "GN", "MF", "PM", "PR", "RM", "ST", "TR"],
+    "quant-ph": [],
+    "stat": ["AP", "CO", "ME", "ML", "OT", "TH"],
+}
+
+
+def isValidArxiv(string):
+    """Determine if the string is a valid arXiv identifier
+    (this does not mean that it exists)
+
+    Parameter:
+        string: the string to test
+
+    Output:
+        boolean
+    """
+    if "arxiv:" in string:
+        string = string.replace("arxiv:", "")
+    if re.match(
+        "^[0-9]{4}\.[0-9]{4,5}(v[0-9]+)?$",
+        string,
+    ):
+        return True
+    elif re.match(
+        "^[a-zA-Z]+(\-[a-zA-Z]+)?(\.[a-zA-Z]+(\-[a-zA-Z]+)?)?/[0-9]{7}(v[0-9]+)?$",
+        string,
+    ):
+        if "." in string:
+            matchcat = re.compile(
+                "([a-zA-Z]+(\-[a-zA-Z]+)?)\.([a-zA-Z]+(\-[a-zA-Z]+)?)/"
+            )
+            for t in matchcat.finditer(string):
+                cat = t.group(1)
+                sub = t.group(3)
+            if cat in arxivCategories.keys() and sub in arxivCategories[cat]:
+                return True
+        else:
+            matchcat = re.compile("([a-zA-Z]+(\-[a-zA-Z]+)?)/")
+            for t in matchcat.finditer(string):
+                cat = t.group(1)
+            if cat in arxivCategories.keys():
+                return True
+        return False
+    else:
+        return False
+
+
 def getYear(string):
-    """Use the arxiv id to compute the year"""
-    identif = re.compile("([0-9]{2})([0-9]{2}.[0-9]{4,5}|[0-9]{5})")
+    """Use the arxiv id to compute the year
+
+    Parameter:
+        string: the arxiv identifier
+
+    Output:
+        a string containing the year of the submission to arXiv
+    """
+    identif = re.compile("(([a-zA-Z\-]+/)([0-9]{7}))|([0-9]{4}\.[0-9]{4,5})")
     try:
         for t in identif.finditer(string):
             if len(t.group()) > 0:
-                a = t.group(1)
+                try:
+                    a = t.group(3)[:2]  # match first type, e.g. hep-ex/0101001
+                except (IndexError, TypeError):
+                    a = t.group(4)[
+                        :2
+                    ]  # match second type, e.g. 1301.0123 or 1501.01234
                 if int(a) > 90:
                     return "19" + a
                 else:
                     return "20" + a
-    except Exception:
+    except (IndexError, TypeError):
         pBLogger.warning(ArxivStrings.errorYearConversion % string)
         return None
 
@@ -50,135 +234,7 @@ class WebSearch(WebInterf, ArxivStrings):
     description = "arXiv fetcher"
     url = "https://export.arxiv.org/api/query"
     urlRss = "https://export.arxiv.org/rss/"
-    categories = {
-        "astro-ph": ["CO", "EP", "GA", "HE", "IM", "SR"],
-        "cond-mat": [
-            "dis-nn",
-            "mes-hall",
-            "mtrl-sci",
-            "other",
-            "quant-gas",
-            "soft",
-            "stat-mech",
-            "str-el",
-            "supr-con",
-        ],
-        "cs": [
-            "AI",
-            "AR",
-            "CC",
-            "CE",
-            "CG",
-            "CL",
-            "CR",
-            "CV",
-            "CY",
-            "DB",
-            "DC",
-            "DL",
-            "DM",
-            "DS",
-            "ET",
-            "FL",
-            "GL",
-            "GR",
-            "GT",
-            "HC",
-            "IR",
-            "IT",
-            "LG",
-            "LO",
-            "MA",
-            "MM",
-            "MS",
-            "NA",
-            "NE",
-            "NI",
-            "OH",
-            "OS",
-            "PF",
-            "PL",
-            "RO",
-            "SC",
-            "SD",
-            "SE",
-            "SI",
-            "SY",
-        ],
-        "econ": ["EM", "GN", "TH"],
-        "eess": ["AS", "IV", "SP"],
-        "gr-qc": [],
-        "hep-ex": [],
-        "hep-lat": [],
-        "hep-ph": [],
-        "hep-th": [],
-        "math": [
-            "AC",
-            "AG",
-            "AP",
-            "AT",
-            "CA",
-            "CO",
-            "CT",
-            "CV",
-            "DG",
-            "DS",
-            "FA",
-            "GM",
-            "GN",
-            "GR",
-            "GT",
-            "HO",
-            "IT",
-            "KT",
-            "LO",
-            "MG",
-            "MP",
-            "NA",
-            "NT",
-            "OA",
-            "OC",
-            "PR",
-            "QA",
-            "RA",
-            "RT",
-            "SG",
-            "SP",
-            "ST",
-        ],
-        "math-ph": [],
-        "nlin": ["AO", "CD", "CG", "PS", "SI"],
-        "nucl-ex": [],
-        "nucl-th": [],
-        "physics": [
-            "acc-ph",
-            "ao-ph",
-            "app-ph",
-            "atm-clus",
-            "atom-ph",
-            "bio-ph",
-            "chem-ph",
-            "class-ph",
-            "comp-ph",
-            "data-an",
-            "ed-ph",
-            "flu-dyn",
-            "gen-ph",
-            "geo-ph",
-            "hist-ph",
-            "ins-det",
-            "med-ph",
-            "optics",
-            "plasm-ph",
-            "pop-ph",
-            "soc-ph",
-            "space-ph",
-        ],
-        "q-bio": ["BM", "CB", "GN", "MN", "NC", "OT", "PE", "QM", "SC", "TO"],
-        "q-fin": ["CP", "EC", "GN", "MF", "PM", "PR", "RM", "ST", "TR"],
-        "quant-ph": [],
-        "stat": ["AP", "CO", "ME", "ML", "OT", "TH"],
-    }
+    categories = arxivCategories
 
     def __init__(self):
         """Initializes the class variables using
@@ -237,16 +293,16 @@ class WebSearch(WebInterf, ArxivStrings):
         Parameters:
             string: the search string
             searchType: the search method in arxiv API (default 'all').
-            The possible values are:
-                ti->    Title
-                au    ->    Author
-                abs    ->    Abstract
-                co    ->    Comment
-                jr    ->    Journal Reference
-                cat    ->    Subject Category
-                rn    ->    Report Number
-                id    ->    Id (use id_list instead)
-                all    ->    All of the above
+                The possible values are:
+                    ti  -> Title
+                    au  -> Author
+                    abs -> Abstract
+                    co  -> Comment
+                    jr  -> Journal Reference
+                    cat -> Subject Category
+                    rn  -> Report Number
+                    id  -> Id (use id_list instead)
+                    all -> All of the above
             additionalArgs: a dictionary of additional arguments
                 that can be passed to self.urlArgs (default None)
             fullDict (logical): return the bibtex dictionary in addition
@@ -256,61 +312,94 @@ class WebSearch(WebInterf, ArxivStrings):
             the bibtex text
             (optional, depending on fullDict): the bibtex Dictionary
         """
+
+        def returnFailed():
+            """Define output of the function when an error occurred"""
+            if fullDict:
+                return "", {}
+            else:
+                return ""
+
+        urlArgs = self.urlArgs.copy()
         if additionalArgs:
-            for k, v in additionalArgs.items():
-                self.urlArgs[k] = v
-        self.urlArgs["search_query"] = searchType + ":" + string
-        url = self.createUrl()
+            try:
+                for k, v in additionalArgs.items():
+                    urlArgs[k] = v
+            except (AttributeError, TypeError):
+                pass
+        urlArgs["search_query"] = searchType + ":" + string
+        url = self.createUrl(urlArgs)
         pBLogger.info(self.searchInfo % (searchType, string, url))
         text = parse_accents_str(self.textFromUrl(url))
         try:
             data = feedparser.parse(text)
-            db = BibDatabase()
-            db.entries = []
-            dictionaries = []
-            for entry in data["entries"]:
-                dictionary = {}
+        except Exception:  # intercept all possible errors
+            pBLogger.exception(self.cannotParseRSS % text, exc_info=True)
+            return returnFailed()
+        if "entries" not in data.keys():
+            pBLogger.exception(self.cannotFindEntriesInFeed % data)
+            return returnFailed()
+        db = BibDatabase()
+        db.entries = []
+        dictionaries = []
+        for entry in data["entries"]:
+            dictionary = {"ENTRYTYPE": "article", "archiveprefix": "arXiv"}
+            try:
                 idArx = (
                     entry["id"]
                     .replace("http://arxiv.org/abs/", "")
                     .replace("https://arxiv.org/abs/", "")
                 )
+            except (AttributeError, KeyError, TypeError):
+                pBLogger.exception(self.cannotReadEntryId % entry)
+                continue
+            else:
                 pos = idArx.find("v")
                 if pos >= 0:
                     idArx = idArx[0:pos]
-                dictionary["ENTRYTYPE"] = "article"
                 dictionary["ID"] = idArx
-                dictionary["archiveprefix"] = "arXiv"
-                dictionary["title"] = entry["title"]
                 dictionary["arxiv"] = idArx
+            for m, k in [["title", "title"], ["doi", "arxiv_doi"]]:
                 try:
-                    dictionary["doi"] = entry["arxiv_doi"]
+                    dictionary[m] = entry[k]
                 except KeyError as e:
                     pBLogger.debug("KeyError: %s" % e)
+            try:
                 dictionary["abstract"] = entry["summary"].replace("\n", " ")
+            except KeyError as e:
+                pBLogger.debug("KeyError: %s" % e)
+            try:
                 dictionary["authors"] = " and ".join(
                     [au["name"] for au in entry["authors"]]
                 )
+            except KeyError as e:
+                pBLogger.debug("KeyError: %s" % e)
+            try:
                 dictionary["primaryclass"] = entry["arxiv_primary_category"]["term"]
+            except KeyError as e:
+                pBLogger.debug("KeyError: %s" % e)
+            try:
                 year = self.getYear(dictionary["arxiv"])
+            except KeyError as e:
+                pBLogger.debug("KeyError: %s" % e)
+            else:
                 if year is not None:
                     dictionary["year"] = year
-                db.entries.append(dictionary)
-                dictionaries.append(dictionary)
-            if fullDict:
+            db.entries.append(dictionary)
+            dictionaries.append(dictionary)
+        if fullDict:
+            try:
                 dictionary = dictionaries[0]
                 for d in dictionaries:
                     if string in d["arxiv"]:
                         dictionary = d
+            except (IndexError, TypeError):
+                pBLogger.exception(self.cannotReadDict)
+                return returnFailed()
+            else:
                 return pbWriter.write(db), dictionary
-            else:
-                return pbWriter.write(db)
-        except Exception:  # intercept all other possible errors
-            pBLogger.exception(self.genericError)
-            if fullDict:
-                return "", {}
-            else:
-                return ""
+        else:
+            return pbWriter.write(db)
 
     def arxivDaily(self, category):
         """Read daily RSS feed for a given category
@@ -345,11 +434,16 @@ class WebSearch(WebInterf, ArxivStrings):
         )
         if sys.version_info[0] < 3:
             text = text.decode("utf-8")
+        text = parse_accents_str(text)
         try:
-            data = feedparser.parse(parse_accents_str(text))
-            entries = []
-            for element in data.entries:
-                tmp = {}
+            data = feedparser.parse(text)
+        except Exception:
+            pBLogger.exception(self.cannotParseRSS % text)
+            return False
+        entries = []
+        for element in data.entries:
+            tmp = {}
+            try:
                 tmp["eprint"] = element["id"].split("/")[-1]
                 tmp["abstract"] = (
                     element["summary"]
@@ -391,8 +485,9 @@ class WebSearch(WebInterf, ArxivStrings):
                     if m != ""
                 ][0]
                 tmp["title"] = element["title"].replace(parenthesis, "")
+            except (IndexError, KeyError, TypeError):
+                pBLogger.warning(self.cannotReadItem)
+                continue
+            else:
                 entries.append(tmp)
-            return entries
-        except Exception:
-            pBLogger.error(self.cannotParseRSS % text, exc_info=True)
-            return False
+        return entries
