@@ -4,4 +4,4 @@ This file is part of the physbiblio package.
 """
 from physbiblio import __author__, __email__, __version__, __version_date__
 
-__all__ = ["test_webimport"]
+__all__ = ["test_isbn", "test_inspire", "test_webimport"]
