@@ -21,7 +21,6 @@ try:
     from physbiblio.config import pbConfig
     from physbiblio.parseAccents import parse_accents_str
     from physbiblio.setuptests import *
-    from physbiblio.webimport.inspireoai import get_journal_ref_xml
     from physbiblio.webimport.webInterf import PBSession, WebInterf, physBiblioWeb
 except ImportError:
     print("Could not find physbiblio and its modules!")
@@ -84,7 +83,7 @@ class TestWebImportMethods(unittest.TestCase):
             "inspire": [
                 "Gariazzo:2015rra",
                 """@article{Gariazzo:2015rra,
-    author = "Gariazzo, S. and Giunti, C. and Laveder, M. and Li, Y.F. and Zavanin, E.M.",
+    author = "Gariazzo, S. and Giunti, C. and Laveder, M. and Li, Y. F. and Zavanin, E. M.",
     title = "{Light sterile neutrinos}",
     eprint = "1507.08204",
     archivePrefix = "arXiv",
@@ -96,43 +95,6 @@ class TestWebImportMethods(unittest.TestCase):
     year = "2016"
 }""",
             ],
-            "inspireoai": [
-                "1385583",
-                {
-                    "doi": "10.1088/0954-3899/43/3/033001",
-                    "arxiv": "1507.08204",
-                    "bibkey": "Gariazzo:2015rra",
-                    "ads": "2015JPhG...43c3001G",
-                    "journal": "J.Phys.",
-                    "volume": "G43",
-                    "year": "2016",
-                    "pages": "033001",
-                    "firstdate": "2015-07-29",
-                    "pubdate": "2016-01-13",
-                    "author": "Gariazzo, S. and Giunti, C. and Laveder, M. "
-                    + "and Li, Y.F. and Zavanin, E.M.",
-                    "collaboration": None,
-                    "primaryclass": "hep-ph",
-                    "archiveprefix": "arXiv",
-                    "eprint": "1507.08204",
-                    "title": "Light sterile neutrinos",
-                    "isbn": None,
-                    "ENTRYTYPE": "article",
-                    "oldkeys": "",
-                    "bibtex": "@Article{Gariazzo:2015rra,\n        "
-                    + 'author = "Gariazzo, S. and Giunti, C. and '
-                    + 'Laveder, M. and Li, Y.F. and Zavanin, E.M.",\n  '
-                    + '       title = "{Light sterile neutrinos}",\n   '
-                    + '    journal = "J.Phys.",\n        volume = "G43",\n '
-                    + '         year = "2016",\n         pages = "033001",\n '
-                    + 'archiveprefix = "arXiv",\n  primaryclass = "hep-ph",\n '
-                    + '       eprint = "1507.08204",\n           doi = '
-                    + '"10.1088/0954-3899/43/3/033001",\n}\n\n',
-                    "id": "1385583",
-                    "link": "%s10.1088/0954-3899/43/3/033001" % pbConfig.doiUrl,
-                    "reportnumber": None,
-                },
-            ],
             "isbn": [
                 "9781107013957",
                 """@book{9781107013957,
@@ -150,12 +112,7 @@ class TestWebImportMethods(unittest.TestCase):
         }
         for method, strings in tests.items():
             print(method)
-            if method == "inspireoai":
-                self.assertEqual(
-                    physBiblioWeb.webSearch[method].retrieveOAIData(strings[0]),
-                    strings[1],
-                )
-            elif method == "arxiv":
+            if method == "arxiv":
                 self.assertEqual(
                     physBiblioWeb.webSearch[method]
                     .retrieveUrlFirst(strings[0], searchType="id")
@@ -179,72 +136,18 @@ class TestWebImportMethods(unittest.TestCase):
                     physBiblioWeb.webSearch[method].retrieveUrlAll(strings[0]).strip(),
                     strings[1].strip(),
                 )
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspire"].retrieveInspireID(tests["inspire"][0]),
-            u"1385583",
-        )
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspire"].retrieveInspireID(
-                tests["doi"][0], isDoi=True
-            ),
-            u"1385583",
-        )
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspire"].retrieveInspireID(
-                tests["arxiv"][0], isArxiv=True
-            ),
-            u"1385583",
-        )
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspire"].retrieveInspireID(
-                "arxiv:" + tests["arxiv"][0], isArxiv=True
-            ),
-            u"1385583",
-        )
 
     def test_methods_insuccess(self):
         """Test webimport using missing and/or invalid identifiers"""
         print(physBiblioWeb.webSearch.keys())
+        self.maxDiff = None
         tests = {
             "arxiv": ["1801.15000", ""],
             "doi": ["10.1088/9999-3899/43/a/033001", ""],
             "inspire": ["Gariazzo:2014rra", ""],
             "isbn": ["978019850871a", ""],
         }
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspireoai"].retrieveOAIData("1110620"),
-            {
-                "doi": None,
-                "arxiv": None,
-                "bibkey": None,
-                "ads": None,
-                "journal": None,
-                "volume": None,
-                "year": None,
-                "pages": None,
-                "firstdate": None,
-                "pubdate": None,
-                "author": " and Tauber, Jan",
-                "collaboration": "Planck",
-                "title": "Anisotropies of the Cosmic Background Radiation Field",
-                "isbn": None,
-                "ENTRYTYPE": "article",
-                "oldkeys": "",
-                "bibtex": '@Article{,\n        author = " and Tauber, Jan",'
-                + '\n collaboration = "Planck",\n         title = "'
-                + '{Anisotropies of the Cosmic Background Radiation Field}",\n}'
-                + "\n\n",
-                "id": "1110620",
-                "archiveprefix": None,
-                "eprint": None,
-                "link": None,
-                "primaryclass": None,
-                "reportnumber": None,
-            },
-        )
-        self.assertFalse(
-            physBiblioWeb.webSearch["inspireoai"].retrieveOAIData("9999999")
-        )
+        self.assertFalse(physBiblioWeb.webSearch["inspire"].retrieveOAIData("9999999"))
         for method, strings in tests.items():
             print(method)
             res = physBiblioWeb.webSearch[method].retrieveUrlFirst(strings[0])
@@ -254,164 +157,6 @@ class TestWebImportMethods(unittest.TestCase):
                 physBiblioWeb.webSearch[method].retrieveUrlAll(strings[0]).strip(),
                 strings[1].strip(),
             )
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspire"].retrieveInspireID(tests["inspire"][0]),
-            "",
-        )
-
-    def test_inspireoai_other(self):
-        """test auxiliary functions in inspireoai module"""
-        self.maxDiff = None
-        marcxmlRecord1 = physBiblioWeb.webSearch["inspireoai"].oai.getRecord(
-            metadataPrefix="marcxml", identifier="oai:inspirehep.net:1385583"
-        )[1]
-        marcxmlRecord2 = physBiblioWeb.webSearch["inspireoai"].oai.getRecord(
-            metadataPrefix="marcxml", identifier="oai:inspirehep.net:1414175"
-        )[1]
-        self.assertEqual(
-            get_journal_ref_xml(marcxmlRecord1),
-            (
-                ["J.Phys."],
-                ["G43"],
-                ["2016"],
-                ["033001"],
-                [None],
-                [None],
-                [None],
-                [None],
-            ),
-        )
-        self.assertEqual(
-            get_journal_ref_xml(marcxmlRecord2),
-            (
-                [None],
-                [None],
-                ["2017"],
-                ["469-475"],
-                [None],
-                [None],
-                [None],
-                ["C15-08-20"],
-            ),
-        )
-        dict1a = physBiblioWeb.webSearch["inspireoai"].readRecord(marcxmlRecord1)
-        dict1b = physBiblioWeb.webSearch["inspireoai"].readRecord(
-            marcxmlRecord1, readConferenceTitle=True
-        )
-        self.assertEqual(dict1a, dict1b)
-        self.assertEqual(
-            dict1a,
-            {
-                "doi": "10.1088/0954-3899/43/3/033001",
-                "arxiv": "1507.08204",
-                "bibkey": "Gariazzo:2015rra",
-                "ads": "2015JPhG...43c3001G",
-                "journal": "J.Phys.",
-                "volume": "G43",
-                "year": "2016",
-                "pages": "033001",
-                "firstdate": "2015-07-29",
-                "pubdate": "2016-01-13",
-                "author": "Gariazzo, S. and Giunti, C. and Laveder, M. and "
-                + "Li, Y.F. and Zavanin, E.M.",
-                "collaboration": None,
-                "primaryclass": "hep-ph",
-                "archiveprefix": "arXiv",
-                "eprint": "1507.08204",
-                "reportnumber": None,
-                "title": "Light sterile neutrinos",
-                "isbn": None,
-                "ENTRYTYPE": "article",
-                "oldkeys": "",
-                "link": "%s10.1088/0954-3899/43/3/033001" % pbConfig.doiUrl,
-                "bibtex": "@Article{Gariazzo:2015rra,\n        "
-                + 'author = "Gariazzo, S. and Giunti, C. and Laveder, M. '
-                + 'and Li, Y.F. and Zavanin, E.M.",\n         title = "'
-                + '{Light sterile neutrinos}",\n       journal = '
-                + '"J.Phys.",\n        volume = "G43",\n          year = '
-                + '"2016",\n         pages = "033001",\n archiveprefix = '
-                + '"arXiv",\n  primaryclass = "hep-ph",\n        eprint = '
-                + '"1507.08204",\n           doi = '
-                + '"10.1088/0954-3899/43/3/033001",\n}\n\n',
-            },
-        )
-        dict2 = physBiblioWeb.webSearch["inspireoai"].readRecord(
-            marcxmlRecord2, readConferenceTitle=True
-        )
-        self.assertEqual(
-            dict2,
-            {
-                "doi": "10.1142/9789813224568_0076",
-                "arxiv": "1601.01475",
-                "bibkey": "Gariazzo:2016ehl",
-                "ads": None,
-                "journal": None,
-                "volume": None,
-                "year": "2017",
-                "pages": "469-475",
-                "firstdate": "2016-01-07",
-                "pubdate": "2017",
-                "author": "Gariazzo, Stefano",
-                "collaboration": None,
-                "primaryclass": "astro-ph.CO",
-                "archiveprefix": "arXiv",
-                "eprint": "1601.01475",
-                "reportnumber": None,
-                "title": "Light Sterile Neutrinos In Cosmology",
-                "isbn": None,
-                "booktitle": "Proceedings, 17th Lomonosov "
-                + "Conference on Elementary Particle Physics: Moscow, "
-                + "Russia, August 20-26, 2015",
-                "ENTRYTYPE": "inproceedings",
-                "oldkeys": "",
-                "link": "%s10.1142/9789813224568_0076" % pbConfig.doiUrl,
-                "bibtex": "@Inproceedings{Gariazzo:2016ehl,\n        "
-                + 'author = "Gariazzo, Stefano",\n         '
-                + 'title = "{Light Sterile Neutrinos In Cosmology}",'
-                + '\n     booktitle = "{Proceedings, 17th Lomonosov '
-                + "Conference on Elementary Particle Physics: Moscow, "
-                + 'Russia, August 20-26, 2015}",\n          year = '
-                + '"2017",\n         pages = "469-475",\n archiveprefix = '
-                + '"arXiv",\n  primaryclass = "astro-ph.CO",\n        '
-                + 'eprint = "1601.01475",\n           doi = '
-                + '"10.1142/9789813224568_0076",\n}\n\n',
-            },
-        )
-        dict1a["id"] = "1385583"
-        dict2["id"] = "1414175"
-        bibtex1 = '@article{abc,\nauthor="me",}'
-        bibtex2 = "@article{abc,"
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspireoai"].updateBibtex(dict2, bibtex1),
-            (False, bibtex1),
-        )
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspireoai"].updateBibtex(dict1a, bibtex2),
-            (False, bibtex2),
-        )
-        self.assertEqual(
-            physBiblioWeb.webSearch["inspireoai"].updateBibtex(dict1a, bibtex1),
-            (
-                True,
-                '@Article{abc,\n        author = "me",\n       '
-                + 'journal = "J.Phys.",\n        volume = "G43",\n          '
-                + 'year = "2016",\n         pages = "033001",\n           '
-                + 'doi = "10.1088/0954-3899/43/3/033001",\n}\n\n',
-            ),
-        )
-
-    @unittest.skipIf(skipTestsSettings.oai, "Online tests with OAI")
-    def test_inspireoai(self):
-        """test retrieve daily data from inspireOAI"""
-        date1 = (datetime.date.today() - datetime.timedelta(1)).strftime("%Y-%m-%d")
-        date2 = datetime.date.today().strftime("%Y-%m-%d")
-        yren, monen, dayen = date1.split("-")
-        yrst, monst, dayst = date2.split("-")
-        date1 = datetime.datetime(int(yren), int(monen), int(dayen))
-        date2 = datetime.datetime(int(yrst), int(monst), int(dayst))
-        result = physBiblioWeb.webSearch["inspireoai"].retrieveOAIUpdates(date1, date2)
-        self.assertEqual(type(result), list)
-        print(len(result), result[0])
 
 
 class TestWebImportOffline(unittest.TestCase):
@@ -435,7 +180,7 @@ class TestWebImportOffline(unittest.TestCase):
                 total=5,
                 backoff_factor=1.0,
                 status_forcelist=[429, 500, 502, 503, 504],
-                method_whitelist=["HEAD", "GET", "OPTIONS"],
+                allowed_methods=["HEAD", "GET", "OPTIONS"],
             )
             _ha.assert_called_once_with(max_retries=fr)
             _m.assert_any_call("https://", ha)
